@@ -7,6 +7,7 @@ extern "C" {
 void	init_auto_menu( void );
 void	init_auto_mark_all_mbr( void );
 void	init_auto_mark_mbr( long ls_mbr_n );
+void	ver_up_auto_mark_1_0_4( long ls_mbr_n );
 char	*menu_auto_mark( menu_t **pp, menu_t **dflt );
 void	set_menu_auto_mark( menu_t **dflt );
 char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt );
@@ -58,6 +59,9 @@ long	get_auto_mark_cur_n( void );
 auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr );
 char	*get_msg_ttl_auto_mark( long n );
 auto_mark_t	*get_ls_auto_mark( long ls_mbr_n );
+auto_mark_appoint_item_t	*get_ls_auto_mark_appoint_item(
+	long ls_mbr_n, long n
+);
 
 #ifdef __cplusplus
 }
