@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.37 2004/07/26 10:02:44 bowkenken Exp $
-*****************************************************************/
+* $Id: amenu.c,v 1.42 2004/12/20 22:40:42 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -91,7 +91,7 @@ static auto_mark_t	dflt_auto_mark_fight = {
 	FLG_AUTO_MARK_EDIT_CONT,
 };
 
-static auto_mark_t	dflt_auto_mark_fight_pri = {
+static auto_mark_t	dflt_auto_mark_fight_prio = {
 	AUTO_MARK_TRGT_MNSTR,
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_FIGHT,
@@ -107,7 +107,7 @@ static auto_mark_t	dflt_auto_mark_throw = {
 	FLG_NULL,
 };
 
-static auto_mark_t	dflt_auto_mark_throw_pri = {
+static auto_mark_t	dflt_auto_mark_throw_prio = {
 	AUTO_MARK_TRGT_MNSTR,
 	AUTO_MARK_DIST_MEDIUM,
 	AUTO_MARK_ACT_THROW,
@@ -123,7 +123,7 @@ static auto_mark_t	dflt_auto_mark_fight_far = {
 	FLG_NULL,
 };
 
-static auto_mark_t	dflt_auto_mark_fight_far_pri = {
+static auto_mark_t	dflt_auto_mark_fight_far_prio = {
 	AUTO_MARK_TRGT_MNSTR,
 	AUTO_MARK_DIST_FAR,
 	AUTO_MARK_ACT_FIGHT,
@@ -139,7 +139,7 @@ static auto_mark_t	dflt_auto_mark_fight_all = {
 	FLG_NULL,
 };
 
-static auto_mark_t	dflt_auto_mark_fight_all_pri = {
+static auto_mark_t	dflt_auto_mark_fight_all_prio = {
 	AUTO_MARK_TRGT_MNSTR,
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_FIGHT,
@@ -241,14 +241,16 @@ static auto_mark_appoint_item_t	auto_mark_appoint_item_dflt
 
 /**/
 
-/*****************************************************************
+/***************************************************************
 * 
-*****************************************************************/
+***************************************************************/
 
 void	init_auto_menu( void )
 {
 	long	i, j, k;
 
+	g_sel_mbr = NULL;
+
 	auto_mark_cur_n = 0;
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
@@ -265,9 +267,9 @@ void	init_auto_menu( void )
 	init_auto_mark_all_mbr();
 }
 
-/*****************************************************************
+/***************************************************************
 * ٤ƤΥСν
-*****************************************************************/
+***************************************************************/
 
 void	init_auto_mark_all_mbr( void )
 {
@@ -277,10 +279,10 @@ void	init_auto_mark_all_mbr( void )
 		init_auto_mark_mbr( i );
 }
 
-/*****************************************************************
+/***************************************************************
 * Сν
 * long ls_mbr_n : СΥꥹֹ
-*****************************************************************/
+***************************************************************/
 
 void	init_auto_mark_mbr( long ls_mbr_n )
 {
@@ -295,10 +297,10 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
 
-	/* Ʈ(ɲ) */
-
 	j = 0;
 
+	/* Ʈ(ɲ) */
+
 	switch( ls_mbr_n ){
 	default:
 	case 0:
@@ -326,23 +328,63 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	case 0:
 	case 1:
 	case 3:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_pri;
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_prio;
 		break;
 	case 2:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_throw_pri;
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_throw_prio;
 		break;
 	case 4:
 	case 5:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far_pri;
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far_prio;
 		break;
 	}
 	strncpy( msg_ttl_auto_mark[j],
-			MSG_NAME_DFLT_AUTO_MARK_FIGHT_PRI,
+			MSG_NAME_DFLT_AUTO_MARK_FIGHT_PRIO,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 	j++;
 
 	/* ܶƮ(ɲ) */
 
+	switch( ls_mbr_n ){
+	default:
+	case 0:
+	case 1:
+	case 2:
+	case 3:
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight;
+		break;
+	case 4:
+	case 5:
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far;
+		break;
+	}
+	strncpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	j++;
+
+	/* ܶƮ() */
+
+	switch( ls_mbr_n ){
+	default:
+	case 0:
+	case 1:
+	case 2:
+	case 3:
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_prio;
+		break;
+	case 4:
+	case 5:
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far_prio;
+		break;
+	}
+	strncpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	j++;
+
+	/* (ɲ) */
+
 	if( j < AUTO_MARK_MAX_N ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
 		strncpy( msg_ttl_auto_mark[j],
@@ -351,12 +393,12 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	j++;
 
-	/* ܶƮ() */
+	/* () */
 
 	if( j < AUTO_MARK_MAX_N ){
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_pri;
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
 		strncpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRI,
+				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
 	j++;
@@ -390,12 +432,117 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 }
 
-/*****************************************************************
+/***************************************************************
+* ΥСʥå
+* long ls_mbr_n : СΥꥹֹ
+***************************************************************/
+
+void	ver_up_auto_mark_1_0_4( long ls_mbr_n )
+{
+	long	j;
+	char	*msg_no_throw = MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW;
+	char	*msg_no_throw_prio
+			= MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO;
+
+	j = 0;
+
+	/* õ */
+
+	for( ; j < AUTO_MARK_MAX_N; j++ ){
+		if( ls_auto_mark[ls_mbr_n][j].trgt == AUTO_MARK_TRGT_CLEAR )
+			break;
+	}
+
+	/* (ɲ) */
+
+	if( j < AUTO_MARK_MAX_N ){
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
+		strncpy( msg_ttl_auto_mark[j],
+				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+	j++;
+
+	/* õ */
+
+	for( ; j < AUTO_MARK_MAX_N; j++ ){
+		if( ls_auto_mark[ls_mbr_n][j].trgt == AUTO_MARK_TRGT_CLEAR )
+			break;
+	}
+
+	/* () */
+
+	if( j < AUTO_MARK_MAX_N ){
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
+		strncpy( msg_ttl_auto_mark[j],
+				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+	j++;
+
+	/* ܶƮ(ɲ)õ */
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		if( strcmp( msg_ttl_auto_mark[j],
+				msg_no_throw ) == 0 ){
+			break;
+		}
+	}
+
+	/* ܶƮ(ɲ) */
+
+	if( j < AUTO_MARK_MAX_N ){
+		switch( ls_mbr_n ){
+		default:
+		case 0:
+		case 1:
+		case 2:
+		case 3:
+			ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight;
+			break;
+		case 4:
+		case 5:
+			ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far;
+			break;
+		}
+	}
+
+	/* ܶƮ()õ */
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		if( strcmp( msg_ttl_auto_mark[j],
+				msg_no_throw_prio ) == 0 ){
+			break;
+		}
+	}
+
+	/* ܶƮ() */
+
+	if( j < AUTO_MARK_MAX_N ){
+		switch( ls_mbr_n ){
+		default:
+		case 0:
+		case 1:
+		case 2:
+		case 3:
+			ls_auto_mark[ls_mbr_n][j]
+					= dflt_auto_mark_fight_prio;
+			break;
+		case 4:
+		case 5:
+			ls_auto_mark[ls_mbr_n][j]
+					= dflt_auto_mark_fight_far_prio;
+			break;
+		}
+	}
+}
+
+/***************************************************************
 * ˥塼
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*menu_auto_mark( menu_t **pp, menu_t **dflt )
 {
@@ -408,10 +555,10 @@ char	*menu_auto_mark( menu_t **pp, menu_t **dflt )
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * ˥塼ΥꥹȤ
 * menu_t **dflt : ˥塼Υǥե
-*****************************************************************/
+***************************************************************/
 
 void	set_menu_auto_mark( menu_t **dflt )
 {
@@ -497,12 +644,12 @@ void	set_menu_auto_mark( menu_t **dflt )
 	p[k].path[0] = '\0';
 }
 
-/*****************************************************************
+/***************************************************************
 * ˥塼Ǽ¹Ԥ򤵤줿˸ƤФ
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt )
 {
@@ -525,10 +672,10 @@ char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt )
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Ū˥ޡʤʤϢ³ޡ
 * mbr_t *mbr : С
-*****************************************************************/
+***************************************************************/
 
 void	set_auto_mark_cont( mbr_t *mbr )
 {
@@ -541,11 +688,11 @@ void	set_auto_mark_cont( mbr_t *mbr )
 	}
 }
 
-/*****************************************************************
+/***************************************************************
 * ˥塼¹Ԥ
 * mbr_t *mbr : С
 * return : Ԥ
-*****************************************************************/
+***************************************************************/
 
 bool_t	exec_menu_auto_mark( mbr_t *mbr )
 {
@@ -602,11 +749,11 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr )
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * 󥹥оݤ˥˥塼¹Ԥ
 * mbr_t *mbr : С
 * return : Ԥ
-*****************************************************************/
+***************************************************************/
 
 bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 {
@@ -686,11 +833,11 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * ƥоݤ˥˥塼¹Ԥ
 * mbr_t *mbr : С
 * return : Ԥ
-*****************************************************************/
+***************************************************************/
 
 bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 {
@@ -777,11 +924,11 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * ɥоݤ˥˥塼¹Ԥ
 * mbr_t *mbr : С
 * return : Ԥ
-*****************************************************************/
+***************************************************************/
 
 bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 {
@@ -868,11 +1015,11 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * Соݤ˥˥塼¹Ԥ
 * mbr_t *mbr : С
 * return : Ԥ
-*****************************************************************/
+***************************************************************/
 
 bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 {
@@ -955,12 +1102,12 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * ˥塼Խ򤵤줿˸ƤФ
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt )
 {
@@ -989,12 +1136,12 @@ char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt )
 	return STR_MENU_ERR;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_edit_init(
 	menu_t **pp, menu_t **dflt
@@ -1065,12 +1212,12 @@ char	*cb_menu_auto_mark_edit_init(
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼оݤ
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_trgt_init(
 	menu_t **pp, menu_t **dflt
@@ -1116,12 +1263,12 @@ char	*cb_menu_auto_mark_trgt_init(
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼оݤ򤷤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_trgt( menu_t **pp, menu_t **dflt )
 {
@@ -1159,12 +1306,12 @@ char	*cb_menu_auto_mark_trgt( menu_t **pp, menu_t **dflt )
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼δֹ礤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_dist_init(
 	menu_t **pp, menu_t **dflt
@@ -1207,12 +1354,12 @@ char	*cb_menu_auto_mark_dist_init(
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼δֹ礤򤷤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_dist( menu_t **pp, menu_t **dflt )
 {
@@ -1222,12 +1369,12 @@ char	*cb_menu_auto_mark_dist( menu_t **pp, menu_t **dflt )
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼ιư
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 {
@@ -1355,12 +1502,12 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼ιư򤷤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_act( menu_t **pp, menu_t **dflt )
 {
@@ -1370,12 +1517,12 @@ char	*cb_menu_auto_mark_act( menu_t **pp, menu_t **dflt )
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼ξ
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_cond_init(
 	menu_t **pp, menu_t **dflt
@@ -1454,12 +1601,12 @@ char	*cb_menu_auto_mark_cond_init(
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼ξ򤷤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt )
 {
@@ -1485,12 +1632,12 @@ char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt )
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼Υƥ̤򤷤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_appoint_item(
 	menu_t **pp, menu_t **dflt
@@ -1560,14 +1707,14 @@ char	*cb_menu_auto_mark_appoint_item(
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼Υƥ̤
 * menu_t *ls : ˥塼
 * long *k : Υ˥塼ֹ
 * char mjr_key : 򥭡
 * auto_mark_appoint_item_t **apo : ƥ̤Υǡ
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*set_menu_auto_mark_appoint_item(
 	menu_t *ls, long *k, char mjr_key,
@@ -1617,12 +1764,12 @@ char	*set_menu_auto_mark_appoint_item(
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼Υƥ̤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_appoint_item_init(
 	menu_t **pp, menu_t **dflt
@@ -1649,12 +1796,12 @@ char	*cb_menu_auto_mark_appoint_item_init(
 	return NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼Υƥ̤ξܺ٤򤷤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_appoint_item_mnr(
 	menu_t **pp, menu_t **dflt
@@ -1671,12 +1818,12 @@ char	*cb_menu_auto_mark_appoint_item_mnr(
 	return STR_MENU_CANCEL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼Ϣ³ޡ
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt )
 {
@@ -1691,12 +1838,12 @@ char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt )
 	return STR_MENU_CANCEL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Խ˥塼ͥ
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt )
 {
@@ -1711,12 +1858,12 @@ char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt )
 	return STR_MENU_CANCEL;
 }
 
-/*****************************************************************
+/***************************************************************
 * Ƭ¤ٴ˥塼򤷤
 * menu_t **pp : ˥塼
 * menu_t **dflt : ˥塼Υǥե
 * return : ˥塼ΰư
-*****************************************************************/
+***************************************************************/
 
 char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt )
 {
@@ -1759,11 +1906,11 @@ char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt )
 	return "/Auto mark/0";
 }
 
-/*****************************************************************
+/***************************************************************
 * оݤоݤʸѴ
 * mbr_t *mbr : С
 * return : оݤΥ˥塼ʸ
-*****************************************************************/
+***************************************************************/
 
 char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr )
 {
@@ -1787,11 +1934,11 @@ char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr )
 	return MSG_NOT_NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * ֹ礤ֹ礤ʸѴ
 * mbr_t *mbr : С
 * return : ֹ礤Υ˥塼ʸ
-*****************************************************************/
+***************************************************************/
 
 char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr )
 {
@@ -1815,11 +1962,11 @@ char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr )
 	return MSG_NOT_NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * ưưʸѴ
 * mbr_t *mbr : С
 * return : ưΥ˥塼ʸ
-*****************************************************************/
+***************************************************************/
 
 char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr )
 {
@@ -1861,11 +2008,11 @@ char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr )
 	return MSG_NOT_NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * 狼ʸѴ
 * mbr_t *mbr : С
 * return : Υ˥塼ʸ
-*****************************************************************/
+***************************************************************/
 
 char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr )
 {
@@ -1891,20 +2038,20 @@ char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr )
 	return MSG_NOT_NULL;
 }
 
-/*****************************************************************
+/***************************************************************
 * ߤμưޡֹ֤
 * return : ߤμưޡֹ
-*****************************************************************/
+***************************************************************/
 
 long	get_auto_mark_cur_n( void )
 {
 	return auto_mark_cur_n;
 }
 
-/*****************************************************************
+/***************************************************************
 * ߤμưޡΥƥ̤֤
 * return : ߤμưޡΥƥ
-*****************************************************************/
+***************************************************************/
 
 auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr )
 {
@@ -1918,22 +2065,22 @@ auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr )
 	return auto_mark_appoint_item[mbr->ls_mbr_n][n];
 }
 
-/*****************************************************************
+/***************************************************************
 * ưޡΥȥʸ֤
 * n : ưޡֹ
 * return : ưޡΥȥʸ֤
-*****************************************************************/
+***************************************************************/
 
 char	*get_msg_ttl_auto_mark( long n )
 {
 	return msg_ttl_auto_mark[n];
 }
 
-/*****************************************************************
+/***************************************************************
 * ưޡΥǡ֤
 * long ls_mbr_n : СꥹȤֹ
 * return : ưޡΥǡ֤
-*****************************************************************/
+***************************************************************/
 
 auto_mark_t	*get_ls_auto_mark( long ls_mbr_n )
 {
@@ -1944,3 +2091,26 @@ auto_mark_t	*get_ls_auto_mark( long ls_mbr_n )
 
 	return( ls_auto_mark[ls_mbr_n] );
 }
+
+/***************************************************************
+* ưޡΥƥΥǡ֤
+* long ls_mbr_n : СꥹȤֹ
+* n : ưޡֹ
+* return : ưޡΥƥΥǡ֤
+***************************************************************/
+
+auto_mark_appoint_item_t	*get_ls_auto_mark_appoint_item(
+	long ls_mbr_n, long n
+)
+{
+	if( ls_mbr_n < 0 )
+		return NULL;
+	if( ls_mbr_n >= LS_MBR_MAX_N )
+		return NULL;
+	if( n < 0 )
+		return NULL;
+	if( n >= AUTO_MARK_MAX_N )
+		return NULL;
+
+	return( auto_mark_appoint_item[ls_mbr_n][n] );
+}
