@@ -100,15 +100,21 @@ void	chr_srch_begin( chr_t *chr );
 void	chr_srch_end( chr_t *chr );
 bool_t	chk_infra_vision( chr_t *chr );
 bool_t	chr_light_up( chr_t *chr, bool_t flg_on );
-void	put_chr( chr_t *chr, long x, long y, bool_t flg_clr_map );
+void	put_chr( chr_t *chr, long x, long y );
 void	exp_chr(
 	chr_t *chr,
 	long exp,
+	bool_t flg_set_max,
 	bool_t flg_print_exp,
 	bool_t flg_print_lev
 );
-void	chk_lev_up( chr_t *chr, bool_t flg_draw );
-bool_t	set_lev_up( chr_t *chr, abl_kind_t abl, long add, bool_t flg_draw );
+void	chk_lev_up( chr_t *chr, bool_t flg_set_max, bool_t flg_draw );
+bool_t	set_lev_up(
+	chr_t *chr,
+	abl_kind_t abl,
+	long add,
+	bool_t flg_set_max,
+	bool_t flg_draw );
 void	set_modifier( chr_t *chr );
 void	set_modifier_fx_data_equip( chr_t *chr );
 void	set_modifier_fx_data_fx( chr_t *chr );
@@ -127,6 +133,7 @@ char	*get_abl_name( abl_kind_t kind );
 abl_kind_t	get_sub_abl( abl_kind_t abl_main );
 long	calc_lev_to_exp( long lev, abl_kind_t abl );
 long	calc_need_exp( long lev, abl_kind_t abl );
+long	get_exp( chr_t *chr, abl_kind_t abl );
 long	get_lev( chr_t *chr, abl_kind_t abl );
 long	get_lev_max( chr_t *chr, abl_kind_t abl );
 rate_t	get_resi( chr_t *chr, resi_kind_t resi );
@@ -143,6 +150,7 @@ long	add_mp( chr_t *chr, long n, bool_t flg_vfx );
 rate_t	add_resi( chr_t *chr, resi_kind_t kind, rate_t n, bool_t flg_vfx );
 gold_t	get_chr_gold( chr_t *chr );
 gold_t	add_chr_gold( chr_t *chr, gold_t gold );
+void	curs_attrset_chr( chr_t *chr, long n, bool_t flg_crtcl );
 square_t	*get_square( chr_t *chr );
 void	set_square( chr_t *chr, square_t *sq );
 char	*get_trgt_name( trgt_t *trgt );
