@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.84 2004/07/26 10:02:44 bowkenken Exp $
-*****************************************************************/
+* $Id: chr.h,v 1.87 2004/12/13 14:14:23 bowkenken Exp $
+***************************************************************/
 
 #ifndef	CHR_H
 #define	CHR_H
@@ -42,14 +42,17 @@
 #include	"mnstr-kind.h"
 #include	"item-kind.h"
 
-/**/
+/***************************************************************/
 
+/*  */
 #define	ROLL_BASE	10
 
 /* 饯Υ٥ȡµܤΥ٥ȤΨ */
 #define	RATE_LEV_PER_DUN_LEV	((rate_t)30)
 
-/* ̾κʸ */
+/***************************************************************
+* ̾κʸ
+***************************************************************/
 
 #define	CHR_NAME_MAX_LEN	80	/* 饯 */
 #define	MBR_NAME_MAX_LEN	16	/* С */
@@ -58,14 +61,16 @@
 #define	RACE_STR_MAX_LEN	32	/* ݤ碌ޤ᤿²̾ */
 #define	RACE_NAME_MAX_LEN	16	/* ²̾ */
 
-/* 饯ΰưμκ */
-#define	MOVE_LS_MAX_N	3
+#define	MOVE_LS_MAX_N	3	/* 饯ΰưμκ */
 
 #define	ABL_RATE_MIN_N	((rate_t)0)	/* иͤγ꿶κ */
 #define	ABL_RATE_MAX_N	((rate_t)20)	/* иͤγ꿶κǹ */
 #define	ABL_MAX_LEV	9999	/* ٥κǹ */
 
-/* 饯Υե饰 */
+/***************************************************************
+* 饯Υե饰
+* ֤Ѥϥ֡ǡ⽤
+***************************************************************/
 
 typedef unsigned long	flg_chr_t;
 #define	FLG_CHR_AUTO_FIGHT	(1 << 0)	/* Ũˤ֤Ĥä鹶⤹ */
@@ -82,7 +87,10 @@ typedef unsigned long	flg_chr_t;
 #define	FLG_CHR_CAN_DEL	(1 << 20)	/*  */
 #define	FLG_CHR_CAN_DISMISSAL	(1 << 21)	/* Խ */
 
-/* 饯Υơ */
+/***************************************************************
+* 饯Υơ
+* ֤Ѥϥ֡ǡ⽤
+***************************************************************/
 
 typedef unsigned long	flg_stat_t;
 #define	FLG_STAT_NULL	0
@@ -108,8 +116,9 @@ typedef unsigned long	flg_stat_t;
 #define	FLG_STAT_IRON_BODY	(1 << 19)	/* Ŵ */
 #define	FLG_STAT_PASSWALL	(1 << 20)	/* ȴ */
 
-/*  */
+/***************************************************************/
 
+/*  */
 typedef unsigned long	flg_work_t;
 
 /* 󥹥СȯƤ */
@@ -117,12 +126,16 @@ typedef unsigned long	flg_work_t;
 /* 󥹥˥ƥǤ */
 #define	FLG_WORK_STEAL_END	(1 << 1)
 
-/* 饹 */
+/***************************************************************
+* 饹
+***************************************************************/
 
 #define	CLASS_MAX_N	99	/*  */
 #define	CLASS_NAME_MAX_LEN	20	/* ̾κʸ */
 
-/* 󥫡 */
+/***************************************************************
+* 󥫡
+***************************************************************/
 
 #define	SQUARE_WIDTH	3	/*  */
 #define	SQUARE_HEIGHT	3	/* ⤵ */
@@ -137,12 +150,12 @@ typedef unsigned long	flg_work_t;
 #define	STAGGER_RATE_CHR_DRUNK	((rate_t)50)	/* äƤ */
 
 /* 󥹥λäƤ륢ƥκ */
-
 #define	MNSTR_ITEM_N_MAX_N	3
 
-/******************************************************************/
+/***************************************************************/
 
 /* 饯μ */
+/* ֤Ѥϥ֡ǡ⽤ */
 
 typedef enum {
 	CHR_KIND_NULL,
@@ -159,6 +172,7 @@ typedef struct {
 
 /* ² */
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	MAIN_RACE_HUMAN,
 	MAIN_RACE_HALF_ELF,
@@ -168,6 +182,7 @@ typedef enum {
 	MAIN_RACE_MAX_N,
 } main_race_t;
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	SUB_RACE_NULL,
 	SUB_RACE_CAT,
@@ -189,6 +204,7 @@ typedef struct {
 
 /*  */
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	SEX_NULL,
 
@@ -212,6 +228,7 @@ typedef struct {
 
 /* ⤭ */
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	MOVE_KIND_NULL,
 	MOVE_KIND_STOP,	/*  */
@@ -380,6 +397,7 @@ typedef struct {
 
 /*  */
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	ACT_KIND_NULL,
 	ACT_KIND_MNSTR_FIGHT,
@@ -447,6 +465,7 @@ typedef struct {
 
 /* å */
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	TRGT_KIND_NULL,
 	TRGT_KIND_MBR,
@@ -464,6 +483,7 @@ typedef enum {
 
 /* ֹ礤 */
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	DIST_NEAR,	/* ᤯ */
 	DIST_MEDIUM,	/*  */
@@ -565,6 +585,9 @@ typedef struct {
 	/* ̤ɽ */
 	char	face_mjr, face_mnr;
 
+	/* ܥե饰 */
+	bool_t	flg_boss;
+
 	/* ưŪ˷׻иͤν */
 	rate_t	exp;
 
