@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.50 2004/07/26 10:02:44 bowkenken Exp $
-*****************************************************************/
+* $Id: curs.c,v 1.57 2004/12/26 01:22:16 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 #include	"misc.h"
@@ -79,17 +79,19 @@
 # include	"lnl-dos/stdafx.h"
 #endif	/* D_DOS */
 
-/**/
+/***************************************************************/
 
+/* ס󥹤Ȥäȿž°褹뤫? */
 #define	FLG_PRINT_REVERSE	0
 
-/**/
-
+/* 褬ǽɤΥǥץե饰 */
 static long	flg_curs, flg_curs_draw;
+/* 顼ǽե饰 */
 static bool_t	flg_color;
+/* ߤ° */
 static curs_attr_t	g_current_attr;
 
-/**/
+/* °Υǥե */
 
 static curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 	{ 0, N_MSG_ATTR_NORMAL,
@@ -162,11 +164,9 @@ static curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 		COLOR_YELLOW, COLOR_BLACK, A_REVERSE, },
 };
 
-/**/
-
-/*****************************************************************
+/***************************************************************
 * 
-*****************************************************************/
+***************************************************************/
 
 void	init_curs( void )
 {
@@ -174,10 +174,10 @@ void	init_curs( void )
 	flg_curs_draw = 0;
 }
 
-/*****************************************************************
+/***************************************************************
 * ɽν
 * return : Ȥ뤫
-*****************************************************************/
+***************************************************************/
 
 bool_t	init_curs_color( void )
 {
@@ -189,14 +189,23 @@ bool_t	init_curs_color( void )
 
 	flg_color = TRUE;
 
+# if	HAVE_HAS_COLORS
 	if( !has_colors() ){
 		flg_color = FALSE;
 		return FALSE;
 	}
+# else	/* HAVE_HAS_COLORS */
+	return FALSE;
+# endif	/* HAVE_HAS_COLORS */
+
+# if	HAVE_START_COLOR
 	if( start_color() != OK ){
 		flg_color = FALSE;
 		return FALSE;
 	}
+# else	/* HAVE_START_COLOR */
+	return FALSE;
+# endif	/* HAVE_START_COLOR */
 
 	for( n = 0; n < CURS_ATTR_MAX_N; n++ ){
 		short	pair_n;
@@ -206,16 +215,15 @@ bool_t	init_curs_color( void )
 		g_curs_attr[n].color_pair_n = pair_n;
 	}
 #endif	/* HAVE_LIBCURSES */
-
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * 顼ڥν
 * curs_attr_t *p : ⡼
 * short pair_n : 顼ڥ
 * return : Ȥ뤫
-*****************************************************************/
+***************************************************************/
 
 bool_t	init_curs_color_pair( curs_attr_t *p, short pair_n )
 {
@@ -226,17 +234,19 @@ bool_t	init_curs_color_pair( curs_attr_t *p, short pair_n )
 	if( !flg_color )
 		return FALSE;
 
+# if	HAVE_INIT_PAIR
 	init_pair( pair_n, p->fg, p->bg );
+# endif	/* HAVE_INIT_PAIR */
 	p->color_pair_n = pair_n;
 #endif	/* HAVE_LIBCURSES */
 
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * 뤫Ĵ٤
 * return : 뤫
-*****************************************************************/
+***************************************************************/
 
 bool_t	chk_curs_draw( void )
 {
@@ -249,28 +259,28 @@ bool_t	chk_curs_draw( void )
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * ե饰ͭ
-*****************************************************************/
+***************************************************************/
 
 void	ena_curs_draw( void )
 {
 	flg_curs_draw++;
 }
 
-/*****************************************************************
+/***************************************************************
 * ե饰̵
-*****************************************************************/
+***************************************************************/
 
 void	dis_curs_draw( void )
 {
 	flg_curs_draw--;
 }
 
-/*****************************************************************
+/***************************************************************
 * ü꤬ͭĴ٤
 * return : ü꤬ͭ
-*****************************************************************/
+***************************************************************/
 
 bool_t	chk_curs( void )
 {
@@ -286,9 +296,9 @@ bool_t	chk_curs( void )
 	return TRUE;
 }
 
-/*****************************************************************
+/***************************************************************
 * üͭ
-*****************************************************************/
+***************************************************************/
 
 void	ena_curs( void )
 {
@@ -302,9 +312,9 @@ void	ena_curs( void )
 	}
 }
 
-/*****************************************************************
+/***************************************************************
 * ü̵
-*****************************************************************/
+***************************************************************/
 
 void	dis_curs( void )
 {
@@ -318,11 +328,11 @@ void	dis_curs( void )
 	}
 }
 
-/*****************************************************************
+/***************************************************************
 * ü򥯥ꥢ
 * WINDOW *win : ɥ
 * bool_t bf : 1ԥ뤹뤫
-*****************************************************************/
+***************************************************************/
 
 void	curs_clearok( WINDOW *win, bool_t bf )
 {
@@ -341,9 +351,9 @@ void	curs_clearok( WINDOW *win, bool_t bf )
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * ü
-*****************************************************************/
+***************************************************************/
 
 void	curs_initscr( void )
 {
@@ -363,9 +373,9 @@ void	curs_initscr( void )
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * üѤλ
-*****************************************************************/
+***************************************************************/
 
 void	curs_endwin( void )
 {
@@ -390,11 +400,11 @@ void	curs_endwin( void )
 	flg_curs--;
 }
 
-/*****************************************************************
+/***************************************************************
 * ѥåɤ
 * WINDOW *win : ɥ
 * bool_t bf : 1ԥ뤹뤫
-*****************************************************************/
+***************************************************************/
 
 void	curs_keypad( WINDOW *win, bool_t bf )
 {
@@ -404,15 +414,17 @@ void	curs_keypad( WINDOW *win, bool_t bf )
 #if	HAVE_LIBCURSES
 	if( g_flg_use_keypad ){
 		if( chk_curs() ){
+# if	HAVE_KEYPAD
 			keypad( win, bf );
+# endif	/* HAVE_KEYPAD */
 		}
 	}
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * ̤
-*****************************************************************/
+***************************************************************/
 
 void	curs_refresh( void )
 {
@@ -434,19 +446,19 @@ void	curs_refresh( void )
 	fflush( OUT_FP );
 }
 
-/*****************************************************************
+/***************************************************************
 * ߤ⡼ɤ
 * return : ߤ⡼
-*****************************************************************/
+***************************************************************/
 
 curs_attr_t	get_current_attr( void )
 {
 	return g_current_attr;
 }
 
-/*****************************************************************
+/***************************************************************
 * ǥեȤ⡼ɤ
-*****************************************************************/
+***************************************************************/
 
 void	curs_attrset_dflt( void )
 {
@@ -456,10 +468,10 @@ void	curs_attrset_dflt( void )
 	curs_attrset_dir( &(g_curs_attr[CURS_ATTR_N_NORMAL]) );
 }
 
-/*****************************************************************
+/***************************************************************
 * ꤷֹ⡼ɤ
 * curs_attr_n_t n : ⡼ֹ
-*****************************************************************/
+***************************************************************/
 
 void	curs_attrset_n( curs_attr_n_t n )
 {
@@ -469,10 +481,10 @@ void	curs_attrset_n( curs_attr_n_t n )
 	curs_attrset_dir( &(g_curs_attr[n]) );
 }
 
-/*****************************************************************
+/***************************************************************
 * ߤ⡼ɤ
 * curs_attr_t *attr : ⡼
-*****************************************************************/
+***************************************************************/
 
 void	curs_attrset_dir( curs_attr_t *attr )
 {
@@ -497,10 +509,10 @@ void	curs_attrset_dir( curs_attr_t *attr )
 	curs_attrset( tmp_attr );
 }
 
-/*****************************************************************
+/***************************************************************
 * ⡼ɤ
 * long at : Ͳ⡼
-*****************************************************************/
+***************************************************************/
 
 void	curs_attrset( long at )
 {
@@ -512,7 +524,9 @@ void	curs_attrset( long at )
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
+# if	HAVE_ATTRSET
 		attrset( at );
+# endif	/* HAVE_ATTRSET */
 		return;
 	}
 #endif	/* HAVE_LIBCURSES */
@@ -537,10 +551,10 @@ void	curs_attrset( long at )
 #endif	/* FLG_PRINT_REVERSE */
 }
 
-/*****************************************************************
+/***************************************************************
 * ⡼ɤͭ
 * long at : Ͳ⡼
-*****************************************************************/
+***************************************************************/
 
 void	curs_attron( long at )
 {
@@ -552,7 +566,9 @@ void	curs_attron( long at )
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
+# if	HAVE_ATTRON
 		attron( at );
+# endif	/* HAVE_ATTRON */
 		return;
 	}
 #endif	/* HAVE_LIBCURSES */
@@ -562,10 +578,10 @@ void	curs_attron( long at )
 #endif	/* FLG_PRINT_REVERSE */
 }
 
-/*****************************************************************
+/***************************************************************
 * ⡼ɤ̵
 * long at : Ͳ⡼
-*****************************************************************/
+***************************************************************/
 
 void	curs_attroff( long at )
 {
@@ -577,7 +593,9 @@ void	curs_attroff( long at )
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
+# if	HAVE_ATTROFF
 		attroff( at );
+# endif	/* HAVE_ATTROFF */
 		return;
 	}
 #endif	/* HAVE_LIBCURSES */
@@ -587,72 +605,19 @@ void	curs_attroff( long at )
 #endif	/* FLG_PRINT_REVERSE */
 }
 
-/*****************************************************************
-* 饯μͭ⡼ɤ
-* chr_t *chr : 饯
-* long n : + ʤͭ- ʤ
-* bool_t flg_crtcl : ̡ޤ̿Ū
-*****************************************************************/
-
-void	curs_attrset_chr( chr_t *chr, long n, bool_t flg_crtcl )
-{
-	bool_t	flg_mnstr;
-
-	if( !g_flg_cui )
-		return;
-
-	if( chr == NULL )
-		return;
-
-	flg_mnstr = FALSE;
-	if( chr->kind == CHR_KIND_MNSTR )
-		if( chr->attitude == ATTITUDE_ENEMY )
-			flg_mnstr = TRUE;
-
-	if( flg_mnstr ){
-		if( n >= +1 ){
-			if( flg_crtcl ){
-				curs_attrset_n( CURS_ATTR_N_FX_MBR_CRTCL );
-			} else {
-				curs_attrset_n( CURS_ATTR_N_FX_MNSTR_PLUS );
-			}
-		} else if( n <= -1 ){
-			if( flg_crtcl ){
-				curs_attrset_n( CURS_ATTR_N_FX_MNSTR_CRTCL );
-			} else {
-				curs_attrset_n( CURS_ATTR_N_FX_MNSTR_MINUS );
-			}
-		}
-	} else {
-		if( n >= +1 ){
-			if( flg_crtcl ){
-				curs_attrset_n( CURS_ATTR_N_FX_MNSTR_CRTCL );
-			} else {
-				curs_attrset_n( CURS_ATTR_N_FX_MBR_PLUS );
-			}
-		} else if( n <= -1 ){
-			if( flg_crtcl ){
-				curs_attrset_n( CURS_ATTR_N_FX_MBR_CRTCL );
-			} else {
-				curs_attrset_n( CURS_ATTR_N_FX_MBR_MINUS );
-			}
-		}
-	}
-}
-
-/*****************************************************************
+/***************************************************************
 * ⡼ɤΥơ֥
 * return : ⡼ɤΥơ֥
-*****************************************************************/
+***************************************************************/
 
 curs_attr_t	*get_curs_attr( void )
 {
 	return g_curs_attr;
 }
 
-/*****************************************************************
+/***************************************************************
 * ϥɽͭ
-*****************************************************************/
+***************************************************************/
 
 void	curs_echo( void )
 {
@@ -666,9 +631,9 @@ void	curs_echo( void )
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * ϥɽ̵
-*****************************************************************/
+***************************************************************/
 
 void	curs_noecho( void )
 {
@@ -682,9 +647,9 @@ void	curs_noecho( void )
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * ǥͭ
-*****************************************************************/
+***************************************************************/
 
 void	curs_cbreak( void )
 {
@@ -698,9 +663,9 @@ void	curs_cbreak( void )
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * ǥ̵
-*****************************************************************/
+***************************************************************/
 
 void	curs_nocbreak( void )
 {
@@ -714,9 +679,9 @@ void	curs_nocbreak( void )
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * ϹԽͭ
-*****************************************************************/
+***************************************************************/
 
 void	curs_raw( void )
 {
@@ -730,9 +695,9 @@ void	curs_raw( void )
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * ϹԽ̵
-*****************************************************************/
+***************************************************************/
 
 void	curs_noraw( void )
 {
@@ -746,11 +711,11 @@ void	curs_noraw( void )
 #endif	/* HAVE_LIBCURSES */
 }
 
-/*****************************************************************
+/***************************************************************
 * ư
 * int scrn_y : 
 * int scrn_x : 
-*****************************************************************/
+***************************************************************/
 
 void	curs_move( int scrn_y, int scrn_x )
 {
@@ -783,11 +748,11 @@ void	curs_move( int scrn_y, int scrn_x )
 	fprintf( OUT_FP, "\033[%d;%dH", scrn_y + 1, scrn_x + 1 );
 }
 
-/*****************************************************************
+/***************************************************************
 * ɥʸ
-* char *s : եޥåȡʸ
-* ... : ɽ롦ץ
-*****************************************************************/
+* char *s : եޥåʸ
+* ... : ɽ륪ץ
+***************************************************************/
 
 void	curs_printw( char *s, ... )
 {
@@ -814,9 +779,9 @@ void	curs_printw( char *s, ... )
 	va_end( argptr );
 }
 
-/*****************************************************************
+/***************************************************************
 * ̤򥯥ꥢ
-*****************************************************************/
+***************************************************************/
 
 void	curs_clear( void )
 {
@@ -848,54 +813,56 @@ void	curs_clear( void )
 	}
 }
 
-/*****************************************************************
+/***************************************************************
 * 1ʸ
 * return : ʸ
-*****************************************************************/
+***************************************************************/
 
 int	curs_getch( void )
 {
 	int	c;
+	bool_t	flg_getc = FALSE;
 
 	if( !g_flg_cui )
 		return '\0';
 
+	c = '\0';
+
 #if	HAVE_LIBCURSES
-	if( chk_curs() ){
-		c = getch();
 
-		if( g_flg_echo_key )
-			if( (c != '\0') && (c != -1) )
-				print_msg( FLG_NULL, MSG_ECHO_KEY, c, c );
-
-		return c;
+	if( !flg_getc ){
+		if( chk_curs() ){
+			c = getch();
+			flg_getc = TRUE;
+		}
 	}
+
 #endif	/* HAVE_LIBCURSES */
 
 #ifdef	D_DOS
-	c = getch();
 
-	if( g_flg_echo_key )
-		if( (c != '\0') && (c != -1) )
-			print_msg( FLG_NULL, MSG_ECHO_KEY, c, c );
+	if( !flg_getc ){
+		c = getch();
+		flg_getc = TRUE;
+	}
 
-	return c;
 #else	/* D_DOS */
-	c = getchar();
 
-	if( g_flg_echo_key )
-		if( (c != '\0') && (c != -1) )
-			print_msg( FLG_NULL, MSG_ECHO_KEY, c, c );
+	if( !flg_getc ){
+		c = getchar();
+		flg_getc = TRUE;
+	}
+
+#endif	/* D_DOS */
 
 	return c;
-#endif	/* D_DOS */
 }
 
-/*****************************************************************
+/***************************************************************
 * ʸ
 * char *s : ʸ֤
 * int len : ʸ
-*****************************************************************/
+***************************************************************/
 
 void	curs_getnstr( char *s, int len )
 {
@@ -922,20 +889,20 @@ void	curs_getnstr( char *s, int len )
 	strncpy( s, buf, len );
 }
 
-/*****************************************************************
+/***************************************************************
 * 顼⡼ɤĴ٤
 * return : 顼⡼ɤ
-*****************************************************************/
+***************************************************************/
 
 bool_t	chk_color( void )
 {
 	return flg_color;
 }
 
-/*****************************************************************
+/***************************************************************
 * ̤κԿĴ٤
 * return : Կ
-*****************************************************************/
+***************************************************************/
 
 long	get_max_line( void )
 {
@@ -960,11 +927,11 @@ long	get_max_line( void )
 	return SCREEN_HEIGHT;
 }
 
-/*****************************************************************
+/***************************************************************
 * DOS ѤοѴ
 * curs_attr_t *attr : ⡼
 * return : 
-*****************************************************************/
+***************************************************************/
 
 int	attr_dos( curs_attr_t *attr )
 {
