@@ -10,7 +10,8 @@ void	print_wrn( const char *s, ... );
 void	print_err( const char *s, ... );
 void	print_lex_err( const char *s, ... );
 void	print_words(
-	const char *name, sex_t sex,
+	const char *name,
+	sex_t sex,
 	const char *fmt_female,
 	const char *fmt_male,
 	...
@@ -26,12 +27,14 @@ void	redraw_msg( void );
 void	print_log( void );
 void	print_log_back( long idx );
 long	get_ls_msg_idx( void );
-long	get_ls_msg_page( void );
+long	get_ls_msg_line_per_page( void );
 bool_t	set_msg_mul_line( bool_t flg );
 bool_t	chk_msg_mul_line( void );
 long	get_ls_msg_n( void );
 void	draw_ls_msg( long n );
 void	print_str( long scrn_x, long scrn_y, const char *s, ... );
+bool_t	set_redraw_every_turn( bool_t flg );
+bool_t	chk_redraw_every_turn( void );
 void	wipe_all( void );
 void	redraw_all( void );
 void	draw_map( long map_x, long map_y, long dx, long dy );
@@ -56,25 +59,30 @@ void	draw_all_mbr_stat( void );
 void	draw_mbr_stat( mbr_t *mbr );
 void	draw_misc_stat( void );
 void	draw_misc_stat_time( bool_t flg_force );
-bool_t	vfx_spell( spell_tab_t *tab, long arw_n, pos_t *bgn, pos_t *end );
+bool_t	vfx_spell( spell_tab_t *tab, long arw_n, pos_t bgn[], pos_t end[] );
 void	vfx_spell_typhoon( void );
-void	vfx_spell_conflagration( long arw_n, pos_t *end );
+void	vfx_spell_conflagration( long arw_n, pos_t end[] );
 bool_t	vfx_spell_conflagration_sub( long x, long y, long height );
 void	vfx_spell_earthquake( void );
-void	vfx_spell_thunder( long arw_n, pos_t *end );
+void	vfx_spell_thunder( long arw_n, pos_t end[] );
 void	vfx_spell_inundation( void );
 void	vfx_crtcl( chr_kind_t kind, long x, long y );
 void	vfx_ninja_crtcl( chr_kind_t kind, long x, long y );
 void	get_vfx_attr( curs_attr_t *attr );
 void	set_vfx_attr( const curs_attr_t *attr );
 void	set_vfx_attr_n( curs_attr_n_t n );
-void	vfx_arw( chr_kind_t kind, pos_t *bgn, pos_t *end, char c, long len );
+void	vfx_arw(
+	chr_kind_t kind,
+	pos_t bgn[], pos_t end[],
+	char c, long len );
 void	vfx_arw_line(
-	pos_t *bgn, pos_t *end, const char *str, long len,
+	pos_t bgn[], pos_t end[],
+	const char *str, long len,
 	long frame, long clr_frame, bool_t flg_clr
 );
 void	vfx_arw_mul_line(
-	long arw_n, pos_t *bgn, pos_t *end, const char *str, long len,
+	long arw_n, pos_t bgn[], pos_t end[],
+	const char *str, long len,
 	long frame, long clr_frame, bool_t flg_clr
 );
 void	vfx_num( chr_t *p, long n );
@@ -88,10 +96,10 @@ data_n_t	next_mbr_data(
 	long page_n, data_n_t n, long d,
 	mbr_data_edit_kind_t edit_kind
 );
-bool_t	gets_mbr_name( mbr_t *mbr_p );
-bool_t	gets_mbr_face( mbr_t *mbr_p );
+bool_t	gets_mbr_name( mbr_t *mbr );
+bool_t	gets_mbr_face( mbr_t *mbr );
 bool_t	gets_race_name( mbr_t *mbr );
-bool_t	gets_pet_name( pet_t *pet_p );
+bool_t	gets_pet_name( pet_t *pet );
 void	draw_edit_class_all(
 	class_t *org, class_t *dst,
 	edit_class_t sel_n, bool_t flg_sel_add
@@ -117,22 +125,22 @@ void	wait_clock( long frame );
 long	read_char( long *p );
 long	read_char_wait( long *p );
 long	read_esc( long *p );
-long	get_key( bool_t flg_clr_msg );
-long	get_key_sub( bool_t flg_clr_msg );
-long	get_key_x68k( bool_t flg_clr_msg );
-long	get_key_dos( bool_t flg_clr_msg );
-long	get_key_half_wait( bool_t flg_clr_msg );
-long	get_key_std( bool_t flg_clr_msg );
-long	get_key_no_clr( bool_t flg_clr_msg );
+long	get_key( bool_t flg_clr_key_buf );
+long	get_key_sub( bool_t flg_clr_key_buf );
+long	get_key_x68k( bool_t flg_clr_key_buf );
+long	get_key_dos( void );
+long	get_key_half_wait( void );
+long	get_key_std( void );
+long	get_key_no_clr( void );
 long	get_key_buf_char( void );
 long	get_key_buf_char_sub( void );
 bool_t	set_key_buf_str( const char *s );
-long	get_key_tab_n( char *key );
-char	*get_key_tab_cmd( char *key );
+long	get_key_tab_n( const char *key );
+char	*get_key_tab_cmd( const char *key );
 char	*get_key_tab_cmd_char( long c );
 char	**get_key_tab( void );
-void	set_key_tab( char *key, char *str );
-void	set_key_tab_char( long c, char *str );
+void	set_key_tab( const char *key, const char *str );
+void	set_key_tab_char( long c, const char *str );
 long	*get_clk_tck( void );
 
 #ifdef __cplusplus
