@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw-tab.h,v 1.1 2004/07/26 10:02:44 bowkenken Exp $
-*****************************************************************/
+* $Id: draw-tab.h,v 1.5 2004/12/06 06:18:18 bowkenken Exp $
+***************************************************************/
 
 #ifndef	DRAW_TAB_H
 #define	DRAW_TAB_H
@@ -46,14 +46,21 @@
 
 #define	WIN_STAT_HP_DRAW_MIN_X	0
 #define	WIN_STAT_HP_DRAW_MIN_Y	1
-#define	WIN_STAT_HP_DRAW_WIDTH	(2 + 1 + 1 + 2 + 1\
-		+ WIN_STAT_CURE_HP_DRAW_WIDTH\
-		+ WIN_STAT_MAX_HP_DRAW_WIDTH\
-		+ WIN_STAT_CURE_MP_DRAW_WIDTH\
+#define	WIN_STAT_HP_DRAW_WIDTH	(2 + 1 + 1 + 2 + 1 \
+		+ WIN_STAT_CURE_HP_DRAW_WIDTH \
+		+ WIN_STAT_MAX_HP_DRAW_WIDTH \
+		+ WIN_STAT_CURE_MP_DRAW_WIDTH \
 		+ WIN_STAT_MAX_MP_DRAW_WIDTH)
+
+#define	WIN_STAT_MP_DRAW_MIN_X	\
+		(WIN_STAT_HP_DRAW_MIN_X \
+		+ 2 + WIN_STAT_CURE_HP_DRAW_WIDTH \
+		+ 1 + WIN_STAT_MAX_HP_DRAW_WIDTH + 1)
+#define	WIN_STAT_MP_DRAW_MIN_Y	WIN_STAT_HP_DRAW_MIN_Y
+
 #define	WIN_STAT_CURE_HP_DRAW_WIDTH	4
-#define	WIN_STAT_MAX_HP_DRAW_WIDTH	4
 #define	WIN_STAT_CURE_MP_DRAW_WIDTH	4
+#define	WIN_STAT_MAX_HP_DRAW_WIDTH	4
 #define	WIN_STAT_MAX_MP_DRAW_WIDTH	4
 
 #define	WIN_STAT_ACT_DRAW_MIN_X	(WIN_STAT_NAME_DRAW_WIDTH + 1)
@@ -147,7 +154,7 @@
 
 #define	WIN_MBR_DATA_TURN_TTL_DRAW_MIN_X	0
 #define	WIN_MBR_DATA_TURN_TTL_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_GOLD_TTL_DRAW_MIN_Y + 1)
+		(WIN_MBR_DATA_GOLD_TTL_DRAW_MIN_Y + 2)
 
 
 #define	WIN_MBR_DATA_STAT_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
@@ -256,14 +263,15 @@
 /* page 2/2 */
 
 #define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_X	(0 + 6)
-#define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_Y	0
+#define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_Y	2
 
 #define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 18)
-#define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_Y	0
+#define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_Y	\
+		WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_Y
 
 #define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 25)
-#define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_Y	0
-
+#define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_Y	\
+		WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_Y
 
 #define	WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_X	\
 		(WIN_MBR_DATA_DRAW_MID_X + 6)
@@ -780,7 +788,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 long	data_page_n_tab[] = {
 	0,	/* DATA_N_NULL, */
 
-	0,	/* DATA_N_NAME, */
+	DATA_PAGE_N_ALL,	/* DATA_N_NAME, */
 	0,	/* DATA_N_FACE, */
 	0,	/* DATA_N_RACE_STR, */
 	0,	/* DATA_N_RACE_NAME, */
