@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,13 +25,15 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.31 2004/06/30 13:20:45 bowkenken Exp $
-*****************************************************************/
+* $Id: draw.h,v 1.37 2004/12/25 06:33:08 bowkenken Exp $
+***************************************************************/
 
 #ifndef	DRAW_H
 #define	DRAW_H
 
-/*  */
+/***************************************************************
+* 
+***************************************************************/
 
 #include	<stdio.h>
 
@@ -39,11 +41,14 @@
 #include	"menu.h"
 #include	"request.h"
 
-/**/
+/***************************************************************/
 
-#define	OUT_FP	stdout	/* ϥե롦ݥ */
+/* ϥե롦ݥ */
+#define	OUT_FP	stdout
 
-/* ꡼󡦥 */
+/***************************************************************
+* ꡼󡦥
+***************************************************************/
 
 #define	SCREEN_WIDTH	80
 #define	SCREEN_HEIGHT	24
@@ -55,56 +60,67 @@
 #define	WIN_MAP_WIDTH	20
 #define	WIN_MAP_HEIGHT	20
 
-/* VFX */
+/***************************************************************
+* VFX
+***************************************************************/
 
 #define	VFX_ARW_MAX_N	32
-#define	ANIM_FRAME	60
+
+/* ե졼ࡦ졼 */
+#define	ANIM_FRAME_N	((long)(1.0 * 60.0))
 
 #define	ANIM_LINE_LEN	32
 
-/* ʸVFX */
+/***************************************************************
+* ʸVFX
+***************************************************************/
 
 #define	TYPHOON_DUST_MAX_N	24
 #define	TYPHOON_SPEED	10
 #define	ANIM_TYPHOON_SEC	(4.0)
-#define	ANIM_TYPHOON_FRAME_N	(ANIM_FRAME * 5 / 100)
+#define	ANIM_TYPHOON_FRAME_N	(ANIM_FRAME_N * 5 / 100)
 
 #define	ANIM_CONFLAGRATION_SEC	(4.0)
-#define	ANIM_CONFLAGRATION_FRAME_N	(ANIM_FRAME * 5 / 100)
+#define	ANIM_CONFLAGRATION_FRAME_N	(ANIM_FRAME_N * 5 / 100)
 #define	ANIM_CONFLAGRATION_HEIGHT	(WIN_MAP_DRAW_HEIGHT / 2)
 
 #define	ANIM_EARTHQUAKE_SEC	(4.0)
-#define	ANIM_EARTHQUAKE_FRAME_N	(ANIM_FRAME * 1 / 10)
+#define	ANIM_EARTHQUAKE_FRAME_N	(ANIM_FRAME_N * 1 / 10)
 
-#define	ANIM_THUNDER_FRAME_N	(ANIM_FRAME * 5 / 100)
-#define	ANIM_THUNDER_CLR_FRAME_N	(ANIM_FRAME * 20 / 10)
+#define	ANIM_THUNDER_FRAME_N	(ANIM_FRAME_N * 5 / 100)
+#define	ANIM_THUNDER_CLR_FRAME_N	(ANIM_FRAME_N * 20 / 10)
 #define	ANIM_THUNDER_HEIGHT	(WIN_MAP_DRAW_HEIGHT / 2)
 
-#define	ANIM_INUNDATION_FRAME_N	(ANIM_FRAME * 5 / 100)
-#define	ANIM_INUNDATION_CLR_FRAME_N	(ANIM_FRAME * 20 / 10)
+#define	ANIM_INUNDATION_FRAME_N	(ANIM_FRAME_N * 5 / 100)
+#define	ANIM_INUNDATION_CLR_FRAME_N	(ANIM_FRAME_N * 20 / 10)
 
-/* ¾VFX */
+/***************************************************************
+* ¾VFX
+***************************************************************/
 
 #define	ANIM_ARW_FRAME_N	\
-		((ANIM_FRAME * 15 / 10) - ANIM_ARW_CLR_FRAME_N)
-#define	ANIM_ARW_CLR_FRAME_N	(ANIM_FRAME * 5 / 10)
+		((ANIM_FRAME_N * 15 / 10) - ANIM_ARW_CLR_FRAME_N)
+#define	ANIM_ARW_CLR_FRAME_N	(ANIM_FRAME_N * 5 / 10)
 
 #define	ANIM_CRTCL_FRAME_N	\
-		((ANIM_FRAME * 4 / 10) - ANIM_CRTCL_CLR_FRAME_N)
-#define	ANIM_CRTCL_CLR_FRAME_N	(ANIM_FRAME * 2 / 10)
+		((ANIM_FRAME_N * 4 / 10) - ANIM_CRTCL_CLR_FRAME_N)
+#define	ANIM_CRTCL_CLR_FRAME_N	(ANIM_FRAME_N * 2 / 10)
 #define	ANIM_CRTCL_R	2
-#define	ANIM_CRTCL_WAIT_CLOCK	(ANIM_FRAME * 4 / 10)
+#define	ANIM_CRTCL_WAIT_CLOCK	(ANIM_FRAME_N * 4 / 10)
 #define	STR_ANIM_CRTCL_1	"/"
 #define	STR_ANIM_CRTCL_2	"\\"
 
-#define	ANIM_NUM_FRAME_N	(ANIM_FRAME * 10 / 10)
+#define	ANIM_NUM_FRAME_N	(ANIM_FRAME_N * 10 / 10)
+#define	ANIM_LEV_UP_FRAME_N	(ANIM_FRAME_N * 30 / 10)
 
 #define	ANIM_SPELL_LEN	8
 #define	ANIM_SPELL_FRAME_N	\
-		((ANIM_FRAME * 15 / 10) - ANIM_SPELL_CLR_FRAME_N)
-#define	ANIM_SPELL_CLR_FRAME_N	(ANIM_FRAME * 5 / 10)
+		((ANIM_FRAME_N * 15 / 10) - ANIM_SPELL_CLR_FRAME_N)
+#define	ANIM_SPELL_CLR_FRAME_N	(ANIM_FRAME_N * 5 / 10)
 
-/* ɥΥ */
+/***************************************************************
+* ɥΥ
+***************************************************************/
 
 #define	WIN_MAP_DRAW_MIN_X	0
 #define	WIN_MAP_DRAW_MIN_Y	0
@@ -134,8 +150,6 @@
 #define	WIN_REQUEST_DRAW_WIDTH	40
 #define	WIN_REQUEST_DRAW_MIN_Y	4
 
-/**/
-
 #define	WIN_STAT_DRAW_MIN_X	(WIN_MAP_DRAW_MAX_X + 1 + 1)
 #define	WIN_STAT_DRAW_MIN_Y	0
 #define	WIN_STAT_DRAW_WIDTH	\
@@ -145,26 +159,43 @@
 #define	WIN_STAT_DRAW_MAX_Y	(WIN_STAT_DRAW_MIN_Y \
 		+ ((MBR_MAX_N) * WIN_STAT_DRAW_HEIGHT - 1) - 1)
 
-/* åɽؿΥե饰 */
+/***************************************************************
+* åɽؿΥե饰
+***************************************************************/
 
 typedef unsigned long	flg_msg_t;
-#define	FLG_MSG_ERR	(1 << 0)	/* 顼 */
-#define	FLG_MSG_MORE	(1 << 1)	/* ³Ԥ */
-#define	FLG_MSG_NO_MORE_PREV	(1 << 2)	/* 1³Ԥ̵ */
-#define	FLG_MSG_NO_MORE_NEXT	(1 << 3)	/* 1ļ³Ԥ̵ */
-#define	FLG_MSG_DEBUG	(1 << 4)	/* ǥХåΤɽ */
 
-#define	LS_MSG_DRAW_N	20	/* åꥹȤɽԿ */
-#define	LS_MSG_MAX_N	(LS_MSG_DRAW_N * 8)	/* åκԿ */
+/* 顼 */
+#define	FLG_MSG_ERR	(1 << 0)
 
-/* VFX */
+/* ³Ԥ */
+#define	FLG_MSG_MORE	(1 << 1)
 
-#define	ANIM_FRAME_N	((long)(1.0 * 60.0))	/* ե졼ࡦ졼 */
+/* 1³Ԥ̵ */
+#define	FLG_MSG_NO_MORE_PREV	(1 << 2)
+
+/* 1ļ³Ԥ̵ */
+#define	FLG_MSG_NO_MORE_NEXT	(1 << 3)
+
+/* ³Ԥ̵ */
+#define	FLG_MSG_NO_MORE	(FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT)
+
+/* ǥХåΤɽ */
+#define	FLG_MSG_DEBUG	(1 << 4)
+
+/* åꥹȤɽԿ */
+#define	LS_MSG_DRAW_N	20
+
+/* åκԿ */
+#define	LS_MSG_MAX_N	(LS_MSG_DRAW_N * 8)
+
+/***************************************************************
+* VFXΥե륿
+***************************************************************/
 
 typedef unsigned long	flg_vfx_mbr_t;
 typedef unsigned long	flg_vfx_mnstr_t;
-#define	VFX_WAIT_MIN_N	1
-#define	VFX_WAIT_MAX_N	200
+
 #define	FLG_VFX_MBR_CURE	(1 << 0)
 #define	FLG_VFX_MBR_DAM	(1 << 1)
 #define	FLG_VFX_MBR_CRTCL	(1 << 2)
@@ -174,11 +205,23 @@ typedef unsigned long	flg_vfx_mnstr_t;
 #define	FLG_VFX_MNSTR_CRTCL	(1 << 2)
 #define	FLG_VFX_MNSTR_ARW	(1 << 3)
 
-/* ơ֥ */
+/***************************************************************
+* VFXԤ
+***************************************************************/
 
+#define	VFX_WAIT_MIN_N	1
+#define	VFX_WAIT_MAX_N	200
+
+/***************************************************************
+* ơ֥
+***************************************************************/
+
+/* ơ֥Υ */
 #define	KEY_TAB_MAX_N	512
 
-/* ɽСǡμ */
+/***************************************************************
+* ɽСǡμ
+***************************************************************/
 
 typedef enum {
 	DATA_N_NULL,
@@ -276,7 +319,9 @@ typedef enum {
 	DATA_N_MAX_N,
 } data_n_t;
 
-/* Խ륯饹ǡμ */
+/***************************************************************
+* Խ륯饹ǡμ
+***************************************************************/
 
 typedef enum {
 	EDIT_CLASS_NULL,
