@@ -10,7 +10,7 @@ long	set_crsr_ptn_max_n( long n );
 long	get_crsr_ptn_n( void );
 long	set_crsr_ptn_n( long n );
 void	reset_crsr_ptn( void );
-void	reset_dun( void );
+void	reset_dun( bool_t flg_wall );
 crsr_ptn_t	*get_crsr_ptn( void );
 crsr_ptn_t	*get_sub_crsr_ptn( void );
 bool_t	set_crsr_ptn( crsr_ptn_t *dst, crsr_ptn_t *src );
@@ -42,6 +42,10 @@ void	set_face_door( long dr_n );
 bool_t	chk_find_door( long dr_n );
 bool_t	break_door( long dr_n );
 void	get_near_pos_door( pos_t *pos, door_t *dr, chr_t *chr );
+bool_t	make_hide_cross_path( long ax, long ay );
+bool_t	chk_cross_path( long mx, long my );
+void	hide_cross_path( long mx, long my );
+void	make_stairs_randm( char face );
 void	make_stairs( long x, long y, char face );
 bool_t	set_statue( long x, long y, long dun_lev, bool_t flg_self );
 void	set_map_total( long x, long y, long dx, long dy );
@@ -55,8 +59,8 @@ void	set_map_total_chr( long x, long y, long dx, long dy );
 void	set_map_total_crsr_ptn(
 	pos_t *crsr, crsr_ptn_t *ptn, long x, long y, long dx, long dy
 );
-void	line_path( long x1, long y1, long x2, long y2 );
-void	put_path( long x, long y, long dx, long dy );
+void	line_path( long x1, long y1, long x2, long y2, sect_t sect );
+void	put_path( long x, long y, long dx, long dy, sect_t sect );
 bool_t	open_door( long n );
 bool_t	close_door( long n );
 bool_t	jam_door( long n );
@@ -95,11 +99,12 @@ bool_t	clip_y( long n );
 bool_t	clip_draw_pos( long x, long y );
 bool_t	clip_draw_x( long n );
 bool_t	clip_draw_y( long n );
-bool_t	chk_rate_room( void );
-bool_t	chk_rate_door_open( void );
-bool_t	chk_rate_door_jammed( void );
-bool_t	chk_rate_door_broken( void );
-bool_t	chk_rate_door_secret( void );
+bool_t	chk_rate_room( long dun_lev );
+bool_t	chk_rate_door_open( long dun_lev );
+bool_t	chk_rate_door_jammed( long dun_lev );
+bool_t	chk_rate_door_broken( long dun_lev );
+bool_t	chk_rate_door_secret( long dun_lev );
+bool_t	chk_rate_hide_cross_path( long dun_lev );
 char	get_chr_mjr_crsr( void );
 char	get_chr_mnr_crsr( void );
 char	get_chr_crsr( bool_t flg_mjr );
