@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.65 2004/07/26 10:29:52 bowkenken Exp $
-*****************************************************************/
+* $Id: dun.c,v 1.72 2004/12/26 00:02:15 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -60,7 +60,7 @@
 #include	"chr-prot.h"
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
-/*#include	"pet-prot.h"*/
+#include	"pet-prot.h"
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
@@ -75,20 +75,53 @@
 
 /**/
 
+/* ϩ */
 #define	PATH_WIDTH	3
-#define	AREA_PATH	-1
-#define	STAIRS_UP_MAX_N	2
-#define	STAIRS_DOWN_MAX_N	2
-#define	DOOR_NEAR_R	4
 
+/* ϩɽꥢμ */
+#define	AREA_PATH	-1
+
+/* Ψ */
+
+/* ꥢˤʤΨ */
+#define	RATE_ROOM	((rate_t)50)
+
+/* ɥƤΨ */
+#define	RATE_DOOR_OPEN	((rate_t)10)
+
+/* ɥꤵƤΨ */
+#define	RATE_DOOR_JAMMED	((rate_t)5)
+
+/* ɥƤΨ */
+#define	RATE_DOOR_BROKEN	((rate_t)1)
+
+/* ϩƤΨ */
+#define	RATE_HIDE_CROSS_PATH	((rate_t)100)
+
+/**/
+
+/* 곬ʤο */
+#define	STAIRS_UP_MAX_N	2
+
+/* 곬ʤο */
+#define	STAIRS_DOWN_MAX_N	2
+
+/* 겼ȽγʤޤǤεΥ */
+#define	STAIRS_MAX_R	2
+
+/* 󥹥ΥߥߥåȢǤʤΨ */
 #define	MIMIC_RATE	50
 
+/* ߤγؤƤ NPC ʿѿ */
 #define	DUN_NPC_AVE_N	6
 
+/* 1ֶᤤɥõƱΥˤȽǤΥ */
+#define	DOOR_NEAR_R	4
+
 /**/
 
 static dun_t	dun;
-static area_t	room_ptn_max_n, boss_room_ptn_max_n;
+static area_t	g_room_ptn_max_n, g_boss_room_ptn_max_n;
 
 static crsr_ptn_t	g_crsr_ptn, g_crsr_ptn_usr[CRSR_PTN_MAX_N];
 static crsr_ptn_t	g_sub_crsr_ptn;
@@ -105,7 +138,7 @@ void	init_dun( void )
 {
 	long	i;
 
-	reset_dun();
+	reset_dun( FALSE );
 
 	/* cursor */
 
@@ -180,7 +213,7 @@ void	reset_crsr_ptn( void )
 
 /**/
 
-void	reset_dun( void )
+void	reset_dun( bool_t flg_wall )
 {
 	long	x, y;
 
@@ -188,16 +221,22 @@ void	reset_dun( void )
 		for( x = 0; x < MAP_MAX_X; x++ ){
 			dun.map.sect[y][x] = 'z';
 
-			dun.map.obj.mjr[y][x] = FACE_MJR_WALL;
-			dun.map.obj.mnr[y][x] = FACE_MNR_WALL;
-			dun.map.obj.flg[y][x] = FLG_NULL;
+			if( flg_wall ){
+				dun.map.obj.mjr[y][x] = FACE_MJR_WALL;
+				dun.map.obj.mnr[y][x] = FACE_MNR_WALL;
+				dun.map.obj.flg[y][x] = FLG_NULL;
+			} else {
+				dun.map.obj.mjr[y][x] = FACE_MJR_FLOOR;
+				dun.map.obj.mnr[y][x] = FACE_MNR_FLOOR;
+				dun.map.obj.flg[y][x] = FLG_MAP_OBJ_PASS;
+			}
 
 			dun.map.chr.mjr[y][x] = FACE_MJR_NULL;
 			dun.map.chr.mnr[y][x] = FACE_MNR_NULL;
 			dun.map.chr.flg[y][x] = FLG_NULL;
 
-			dun.map.total.mjr[y][x] = FACE_MJR_WALL;
-			dun.map.total.mnr[y][x] = FACE_MNR_WALL;
+			dun.map.total.mjr[y][x] = dun.map.obj.mjr[y][x];
+			dun.map.total.mnr[y][x] = dun.map.obj.mnr[y][x];
 			dun.map.total.flg[y][x] = FLG_NULL;
 
 			dun.map.light_depth_obj[y][x] = 0;
@@ -316,16 +355,19 @@ void	reset_all( bool_t flg_appear )
 	reset_mnstr();
 	release_all_mbr();
 
+	clr_map_all_mbr();
+	clr_map_all_pet();
+
 	if( dun.lev == 0 ){
 		make_town();
 		if( flg_appear ){
-			if( !appear_party_town( FALSE ) )
-				appear_party( FALSE );
+			if( !appear_party_town() )
+				appear_party();
 		}
 	} else {
 		make_dun();
 		if( flg_appear ){
-			appear_party( FALSE );
+			appear_party();
 		}
 	}
 	put_request_all_obj();
@@ -348,11 +390,11 @@ void	make_dun( void )
 	long	trap_n, trap_max_n;
 	long	i, j;
 
-	reset_dun();
+	reset_dun( TRUE );
 
-	room_ptn_max_n = sizeof( room_ptn )
+	g_room_ptn_max_n = sizeof( room_ptn )
 			/ sizeof( room_ptn_t );
-	boss_room_ptn_max_n = sizeof( boss_room_ptn )
+	g_boss_room_ptn_max_n = sizeof( boss_room_ptn )
 			/ sizeof( room_ptn_t );
 
 	/*  */
@@ -366,13 +408,13 @@ void	make_dun( void )
 	x = randm( AREA_MAP_MAX_X );
 	y = randm( AREA_MAP_MAX_Y );
 	flg_boss = make_area_boss( boss_room_ptn,
-			boss_room_ptn_max_n, x, y );
+			g_boss_room_ptn_max_n, x, y );
 
 	/* ¤ */
 
 	for( y = 0; y < AREA_MAP_MAX_Y; y++ ){
 		for( x = 0; x < AREA_MAP_MAX_X; x++ ){
-			make_area( room_ptn, room_ptn_max_n, x, y );
+			make_area( room_ptn, g_room_ptn_max_n, x, y );
 		}
 	}
 
@@ -408,38 +450,32 @@ void	make_dun( void )
 		}
 	}
 
-	/* ޥåפüɤˤ */
+	/* ϩ¤ */
 
-	make_fence();
-
-	/* ʤ¤ */
-
-	/*  */
-	for( y = 0; y < STAIRS_UP_MAX_N; y++ ){
-		for( x = 0; x < LOOP_MAX_4000; x++ ){
-			long	x, y;
-
-			x = randm( MAP_MAX_X );
-			y = randm( MAP_MAX_Y );
-			if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR ){
-				make_stairs( x, y, FACE_MJR_STAIRS_UP );
-				break;
+	for( y = 0; y < AREA_MAP_MAX_Y; y++ ){
+		for( x = 0; x < AREA_MAP_MAX_X; x++ ){
+			if( !chk_room( x, y ) ){
+				make_hide_cross_path( x, y );
 			}
 		}
 	}
 
-	/*  */
-	for( y = 0; y < STAIRS_DOWN_MAX_N; y++ ){
-		for( x = 0; x < LOOP_MAX_4000; x++ ){
-			long	x, y;
+	/* ޥåפüɤˤ */
 
-			x = randm( MAP_MAX_X );
-			y = randm( MAP_MAX_Y );
-			if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR ){
-				make_stairs( x, y, FACE_MJR_STAIRS_DOWN );
-				break;
-			}
-		}
+	make_fence();
+
+	/* 곬ʤ¤ */
+
+	for( i = 0; i < STAIRS_UP_MAX_N; i++ )
+		make_stairs_randm( FACE_MJR_STAIRS_UP );
+
+	/* 곬ʤ¤ */
+
+	for( i = 0; i < STAIRS_DOWN_MAX_N; i++ ){
+		if( flg_boss )
+			break;
+
+		make_stairs_randm( FACE_MJR_STAIRS_DOWN );
 	}
 
 	/* ꥢƥ */
@@ -472,7 +508,7 @@ void	make_dun( void )
 			dun.map.obj.mnr[y][x] = FACE_MNR_FLOOR;
 			dun.map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
 			if( rate_randm( MIMIC_RATE ) ){
-				make_mnstr( x, y, dun.lev,
+				make_mnstr( x, y, TRUE, dun.lev,
 						MNSTR_KIND_MIMIC );
 			} else {
 				item_t	*item;
@@ -512,7 +548,7 @@ void	make_dun( void )
 			if( mnstr_kind == MNSTR_KIND_NULL )
 				continue;
 
-			make_mnstr( x, y, dun.lev, mnstr_kind );
+			make_mnstr( x, y, TRUE, dun.lev, mnstr_kind );
 		}
 	}
 
@@ -559,7 +595,7 @@ void	make_dun( void )
 
 		x = 1 + randm( MAP_MAX_X - 2 );
 		y = 1 + randm( MAP_MAX_Y - 2 );
-		if( make_mnstr_rand( x, y, dun.lev ) != NULL )
+		if( make_mnstr_rand( x, y, FALSE, dun.lev ) != NULL )
 			mnstr_n++;
 	}
 
@@ -672,7 +708,7 @@ void	make_area( room_ptn_t *ptn, area_t max_n, long x, long y )
 	if( dun.area[y][x] != AREA_PATH )
 		return;
 
-	if( !chk_rate_room() )
+	if( !chk_rate_room( dun.lev ) )
 		return;
 
 	for( i = 0; i < (max_n * LOOP_MAX_100); i++ ){
@@ -834,17 +870,20 @@ void	make_path( long area_x, long area_y )
 
 	/* ʿϩĤʤ */
 
+	/* ٤ϩΣٺɸ */
 	bgn_y = chk_extend_path_h( area_x, area_y, -1 );
-		/* ٤ϩΣٺɸ */
+	/* ٤ϩΣٺɸ */
 	end_y = chk_extend_path_h( area_x, area_y, +1 );
-		/* ٤ϩΣٺɸ */
+	/* ޤʤغɸ */
 	bend_x = 1 + randm( AREA_MAX_X - PATH_WIDTH + 1 - 2 );
-		/* ޤʤغɸ */
 
-	line_path( mx + 0, my + bgn_y, mx + bend_x, my + bgn_y );
-	line_path( mx + bend_x, my + bgn_y, mx + bend_x, my + end_y );
+	line_path( mx + 0, my + bgn_y, mx + bend_x, my + bgn_y,
+			SECT_PATH_H );
+	line_path( mx + bend_x, my + bgn_y, mx + bend_x, my + end_y,
+			SECT_PATH_H );
 	line_path( mx + bend_x, my + end_y,
-			mx + AREA_MAX_X - PATH_WIDTH, my + end_y );
+			mx + AREA_MAX_X - PATH_WIDTH, my + end_y,
+			SECT_PATH_H );
 
 	if( chk_room( area_x - 1, area_y ) ){
 		finish_path( mx + 0,
@@ -858,17 +897,20 @@ void	make_path( long area_x, long area_y )
 
 	/* ľϩĤʤ */
 
+	/* ٤ϩΣغɸ */
 	bgn_x = chk_extend_path_v( area_x, area_y, -1 );
-		/* ٤ϩΣغɸ */
+	/* ٤ϩΣغɸ */
 	end_x = chk_extend_path_v( area_x, area_y, +1 );
-		/* ٤ϩΣغɸ */
+	/* ޤʤٺɸ */
 	bend_y = 1 + randm( AREA_MAX_Y - PATH_WIDTH + 1 - 2 );
-		/* ޤʤٺɸ */
 
-	line_path( mx + bgn_x, my + 0, mx + bgn_x, my + bend_y );
-	line_path( mx + bgn_x, my + bend_y, mx + end_x, my + bend_y );
+	line_path( mx + bgn_x, my + 0, mx + bgn_x, my + bend_y,
+			SECT_PATH_V );
+	line_path( mx + bgn_x, my + bend_y, mx + end_x, my + bend_y,
+			SECT_PATH_V );
 	line_path( mx + end_x, my + bend_y,
-			mx + end_x, my + AREA_MAX_Y - PATH_WIDTH );
+			mx + end_x, my + AREA_MAX_Y - PATH_WIDTH,
+			SECT_PATH_V );
 
 	if( chk_room( area_x, area_y - 1 ) ){
 		finish_path( mx + bgn_x,
@@ -973,28 +1015,36 @@ void	finish_path( long mx, long my, long dx, long dy )
 		for( i = 0; i < AREA_MAX_X; i++ ){
 			if( chk_finish_path( mx, my, -1, 0 ) )
 				break;
-			put_path( mx, my, -1, 0 );	/* ϩ򿭤Ф */
+
+			/* ϩ򿭤Ф */
+			put_path( mx, my, -1, 0, SECT_PATH_DFLT );
 			mx--;
 		}
 	} else if( dx > 0 ){	/* λ */
 		for( i = 0; i < AREA_MAX_X; i++ ){
 			if( chk_finish_path( mx, my, +1, 0 ) )
 				break;
-			put_path( mx, my, +1, 0 );	/* ϩ򿭤Ф */
+
+			/* ϩ򿭤Ф */
+			put_path( mx, my, +1, 0, SECT_PATH_DFLT );
 			mx++;
 		}
 	} else if( dy < 0 ){	/* λ */
 		for( i = 0; i < AREA_MAX_Y; i++ ){
 			if( chk_finish_path( mx, my, 0, -1 ) )
 				break;
-			put_path( mx, my, 0, -1 );	/* ϩ򿭤Ф */
+
+			/* ϩ򿭤Ф */
+			put_path( mx, my, 0, -1, SECT_PATH_DFLT );
 			my--;
 		}
 	} else if( dy > 0 ){	/* λ */
 		for( i = 0; i < AREA_MAX_Y; i++ ){
 			if( chk_finish_path( mx, my, 0, +1 ) )
 				break;
-			put_path( mx, my, 0, +1 );	/* ϩ򿭤Ф */
+
+			/* ϩ򿭤Ф */
+			put_path( mx, my, 0, +1, SECT_PATH_DFLT );
 			my++;
 		}
 	}
@@ -1279,16 +1329,16 @@ door_t	*make_door( long bx, long by, long ex, long ey, char mnr )
 	flg = FLG_NULL;
 
 	if( mnr == FACE_MNR_NULL ){
-		if( chk_rate_door_open() )
+		if( chk_rate_door_open( dun.lev ) )
 			flg |= FLG_DOOR_OPEN;
 
-		if( chk_rate_door_jammed() )
+		if( chk_rate_door_jammed( dun.lev ) )
 			flg |= FLG_DOOR_JAMMED;
 
-		if( chk_rate_door_broken() )
+		if( chk_rate_door_broken( dun.lev ) )
 			flg |= FLG_DOOR_BROKEN;
 
-		if( chk_rate_door_secret() )
+		if( chk_rate_door_secret( dun.lev ) )
 			flg |= FLG_DOOR_SECRET;
 
 		flg &= ~(FLG_DOOR_CHKED);
@@ -1539,6 +1589,174 @@ void	get_near_pos_door( pos_t *pos, door_t *dr, chr_t *chr )
 
 /**/
 
+bool_t	make_hide_cross_path( long ax, long ay )
+{
+	long	x, y;
+
+	if( chk_room( ax, ay ) )
+		return FALSE;
+
+	if( !chk_rate_hide_cross_path( dun.lev ) )
+		return FALSE;
+
+	for( y = 0; y < AREA_MAX_Y; y++ ){
+		for( x = 0; x < AREA_MAX_X; x++ ){
+			long	mx, my;
+
+			mx = ax * AREA_MAX_X + x;
+			my = ay * AREA_MAX_Y + y;
+			if( chk_cross_path( mx, my ) ){
+				hide_cross_path( mx, my );
+			}
+		}
+	}
+
+	return FALSE;
+}
+
+/**/
+
+bool_t	chk_cross_path( long mx, long my )
+{
+	long	x, y;
+	long	i, j;
+
+	if( !clip_pos( mx - 1, my - 1 ) )
+		return FALSE;
+	if( !clip_pos( mx + 1, my + 1 ) )
+		return FALSE;
+
+	for( i = 0; i < PATH_WIDTH; i++ ){
+		for( j = 0; j < PATH_WIDTH; j++ ){
+			x = mx + j;
+			y = my + i;
+			if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR ){
+				return FALSE;
+			}
+		}
+	}
+
+	for( i = 0; i < PATH_WIDTH; i++ ){
+		x = mx + i;
+		y = my - 1;
+		if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
+			return FALSE;
+
+		x = mx + i;
+		y = my + PATH_WIDTH;
+		if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
+			return FALSE;
+
+		x = mx - 1;
+		y = my + i;
+		if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
+			return FALSE;
+
+		x = mx + PATH_WIDTH;
+		y = my + i;
+		if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
+			return FALSE;
+	}
+
+	x = mx - 1;
+	y = my - 1;
+	if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR )
+		return FALSE;
+
+	x = mx + PATH_WIDTH;
+	y = my - 1;
+	if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR )
+		return FALSE;
+
+	x = mx - 1;
+	y = my + PATH_WIDTH;
+	if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR )
+		return FALSE;
+
+	x = mx + PATH_WIDTH;
+	y = my + PATH_WIDTH;
+	if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR )
+		return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
+void	hide_cross_path( long mx, long my )
+{
+	long	bx, by, ex, ey;
+	long	x, y;
+	char	mnr;
+	flg_door_t	flg;
+
+	mnr = FACE_MNR_NULL;
+	flg = FLG_DOOR_SECRET;
+	flg &= ~(FLG_DOOR_OPEN);
+
+	if( randm( 2 ) == 0 ){
+		/* ˥ɥĤ */
+		bx = mx - 1;
+		ex = mx - 1;
+		by = my;
+		ey = my + PATH_WIDTH - 1;
+		make_door_flg( bx, by, ex, ey, mnr, flg );
+
+		/* ˥ɥĤ */
+		bx = mx + PATH_WIDTH;
+		ex = mx + PATH_WIDTH;
+		by = my;
+		ey = my + PATH_WIDTH - 1;
+		make_door_flg( bx, by, ex, ey, mnr, flg );
+
+		for( y = my; y < my + PATH_WIDTH; y++ ){
+			for( x = mx; x < mx + PATH_WIDTH; x++ ){
+				dun.map.sect[y][x] = SECT_PATH_V;
+			}
+		}
+	} else {
+		/* ̤˥ɥĤ */
+		bx = mx;
+		ex = mx + PATH_WIDTH - 1;
+		by = my - 1;
+		ey = my - 1;
+		make_door_flg( bx, by, ex, ey, mnr, flg );
+
+		/* ˥ɥĤ */
+		bx = mx;
+		ex = mx + PATH_WIDTH - 1;
+		by = my + PATH_WIDTH;
+		ey = my + PATH_WIDTH;
+		make_door_flg( bx, by, ex, ey, mnr, flg );
+
+		for( y = my; y < my + PATH_WIDTH; y++ ){
+			for( x = mx; x < mx + PATH_WIDTH; x++ ){
+				dun.map.sect[y][x] = SECT_PATH_H;
+			}
+		}
+	}
+}
+
+/**/
+
+void	make_stairs_randm( char face )
+{
+	long	x, y;
+	long	i;
+
+	for( i = 0; i < LOOP_MAX_4000; i++ ){
+		x = randm( MAP_MAX_X );
+		y = randm( MAP_MAX_Y );
+
+		if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR ){
+			make_stairs( x, y, face );
+			break;
+		}
+	}
+}
+
+/**/
+
 void	make_stairs( long x, long y, char face )
 {
 	char	mjr, mnr;
@@ -1931,7 +2149,7 @@ void	set_map_total_crsr_ptn(
 
 /**/
 
-void	line_path( long x1, long y1, long x2, long y2 )
+void	line_path( long x1, long y1, long x2, long y2, sect_t sect )
 {
 	long	i;
 
@@ -1944,7 +2162,7 @@ void	line_path( long x1, long y1, long x2, long y2 )
 			x2 = xx;
 		}
 		for( i = x1; i <= x2; i++ ){
-			put_path( i, y1, 0, 0 );
+			put_path( i, y1, +1, 0, sect );
 		}
 	} else if( x1 == x2 ){	/* ľ */
 		if( y1 > y2 ){
@@ -1955,49 +2173,38 @@ void	line_path( long x1, long y1, long x2, long y2 )
 			y2 = yy;
 		}
 		for( i = y1; i <= y2; i++ ){
-			put_path( x1, i, 0, 0 );
+			put_path( x1, i, 0, +1, sect );
 		}
 	}
 }
 
 /**/
 
-void	put_path( long x, long y, long dx, long dy )
+void	put_path( long x, long y, long dx, long dy, sect_t sect )
 {
 	long	i, j;
-	long	min_i, max_i;
-	long	min_j, max_j;
-	sect_t	sect;
+	sect_t	dflt_sect;
 	long	xx, yy;
 
-	/* (dx == 0) && (dy == 0)λϥǥե */
-	min_i = 0;
-	max_i = PATH_WIDTH;
-	min_j = 0;
-	max_j = PATH_WIDTH;
-	sect = 'z';
 
 	if( dx < 0 ){
-		min_j = 0;
-		max_j = PATH_WIDTH - 1;
-		sect = 'z';
+		dflt_sect = SECT_PATH_W;
 	} else if( dx > 0 ){
-		min_j = 1;
-		max_j = PATH_WIDTH;
-		sect = 'y';
+		dflt_sect = SECT_PATH_E;
 	} else if( dy < 0 ){
-		min_i = 0;
-		max_i = PATH_WIDTH - 1;
-		sect = 'x';
+		dflt_sect = SECT_PATH_N;
 	} else if( dy > 0 ){
-		min_i = 1;
-		max_i = PATH_WIDTH;
-		sect = 'w';
+		dflt_sect = SECT_PATH_S;
+	} else {
+		dflt_sect = SECT_PATH_N;
 	}
 
-	for( i = min_i; i < max_i; i++ ){
+	if( sect == SECT_PATH_DFLT )
+		sect = dflt_sect;
+
+	for( i = 0; i < PATH_WIDTH; i++ ){
 		yy = y + i;
-		for( j = min_j; j < max_j; j++ ){
+		for( j = 0; j < PATH_WIDTH; j++ ){
 			xx = x + j;
 			dun.map.sect[yy][xx] = sect;
 
@@ -2584,8 +2791,6 @@ door_t	*get_door_near( long x, long y, act_kind_t act_kind )
 			pos1.y = p->y + p->dy - 1;
 		}
 		tmp_r = dx + dy;
-		if( tmp_r > min_r )
-			continue;
 
 		pos2.x = x;
 		pos2.y = y;
@@ -2984,37 +3189,44 @@ bool_t	clip_draw_y( long n )
 
 /**/
 
-bool_t	chk_rate_room( void )
+bool_t	chk_rate_room( long dun_lev )
 {
-	return rate_randm( 50 );
+	return rate_randm( RATE_ROOM );
 }
 
 /**/
 
-bool_t	chk_rate_door_open( void )
+bool_t	chk_rate_door_open( long dun_lev )
 {
-	return rate_randm( 10 );
+	return rate_randm( RATE_DOOR_OPEN );
 }
 
 /**/
 
-bool_t	chk_rate_door_jammed( void )
+bool_t	chk_rate_door_jammed( long dun_lev )
 {
-	return rate_randm( 5 );
+	return rate_randm( RATE_DOOR_JAMMED );
 }
 
 /**/
 
-bool_t	chk_rate_door_broken( void )
+bool_t	chk_rate_door_broken( long dun_lev )
 {
-	return rate_randm( 1 );
+	return rate_randm( RATE_DOOR_BROKEN );
 }
 
 /**/
 
-bool_t	chk_rate_door_secret( void )
+bool_t	chk_rate_door_secret( long dun_lev )
 {
-	return rate_randm( labs( dun.lev ) * 4);
+	return rate_randm( labs( dun_lev ) * 4 );
+}
+
+/**/
+
+bool_t	chk_rate_hide_cross_path( long dun_lev )
+{
+	return rate_randm( RATE_HIDE_CROSS_PATH );
 }
 
 /**/
