@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.h,v 1.25 2004/07/24 07:32:40 bowkenken Exp $
-*****************************************************************/
+* $Id: dun.h,v 1.28 2004/12/20 21:17:54 bowkenken Exp $
+***************************************************************/
 
 #ifndef	DUN_H
 #define	DUN_H
@@ -38,10 +38,8 @@
 
 /**/
 
-#define	DUN_MAX_LEV_FLOOR	1000	/* Ͼκ糬 */
-#define	DUN_MAX_LEV_BASE	1000	/* ϲκ糬 */
-
-#define	STAIRS_MAX_R	2	/* ꡢꤽ줾γʤο */
+#define	DUN_MAX_LEV_FLOOR	10000	/* Ͼκ糬 */
+#define	DUN_MAX_LEV_BASE	10000	/* ϲκ糬 */
 
 /* ޥåפι */
 
@@ -57,6 +55,13 @@
 /* ǥեȤΥ */
 
 #define	SECT_NULL	'a'
+#define	SECT_PATH_DFLT	' '
+#define	SECT_PATH_H	'H'
+#define	SECT_PATH_V	'V'
+#define	SECT_PATH_N	'N'
+#define	SECT_PATH_S	'S'
+#define	SECT_PATH_E	'E'
+#define	SECT_PATH_W	'W'
 
 /* ե饰 */
 
@@ -137,7 +142,7 @@ typedef unsigned long	flg_map_t;
 
 #define	FACE_MJR_SQUARE	'%'
 
-/* ɥ */
+/* ɥκ */
 
 #define	DOOR_MAX_N	64
 
