@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.94 2004/07/27 23:40:22 bowkenken Exp $
-*****************************************************************/
+* $Id: fight.c,v 1.100 2004/12/25 01:43:50 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -1013,8 +1013,11 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	/* Ƥ */
 
 	if( chk_flg( d_p->stat, FLG_STAT_IRON_BODY ) ){
+		curs_attrset_chr( d_p, +1, FALSE );
 		print_msg( FLG_NULL, MSG_REPEL_ATTACK,
 				d_p->name, o_p->name );
+		curs_attrset_dflt();
+
 		return FALSE;
 	}
 
@@ -1042,6 +1045,8 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	if( !flg_serious )
 		o_dam = 0;
 
+	/* ˡ路ʤå */
+
 	if( !flg_crtcl )
 		if( chk_magic_protect( o_p, d_p, attack->flg_throw ) )
 			o_dam = 0;
@@ -1077,7 +1082,7 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 		if( o_lev >= d_lev )
 			break;
 
-		exp_chr( (mbr_t *)o_p, TRAINING_EXP, TRUE, TRUE );
+		exp_chr( (mbr_t *)o_p, TRAINING_EXP, FALSE, TRUE, TRUE );
 	} while( 0 );
 
 	/* ɲø */
@@ -1237,7 +1242,7 @@ bool_t	spell_attack(
 	/* ᡼ɽ */
 
 	curs_attrset_chr( d_p, -1, FALSE );
-	print_msg( FLG_NULL, MSG_FIGHT_HIT_STD, d_name, dam );
+	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_HIT_STD, d_name, dam );
 	curs_attrset_dflt();
 
 	/* HP򸺤餹 */
@@ -1537,19 +1542,16 @@ long	get_hit( chr_t *p, const attack_t *attack )
 
 	if( abl == ABL_KIND_MON ){
 		long	n;
-		rate_t	rate;
 
 		n = get_lev( p, abl );
 		wpn_hit += HIT_MON_MUL * n;
 		if( n > 0 )
 			wpn_hit += HIT_MON_ADD;
-
-		if( p->kind == CHR_KIND_MBR ){
-			rate = calc_rate_abl_equip( p, ABL_KIND_MON );
-			hit = hit * rate / _100_PERCENT;
-		}
 	}
 
+	if( p->kind == CHR_KIND_MBR )
+		hit = hit * calc_rate_abl_equip( p, abl ) / _100_PERCENT;
+
 	/* FXͤä */
 
 	wpn_hit += p->fx_data.wpn_hit;
@@ -1604,19 +1606,16 @@ long	get_dam( chr_t *p, const attack_t *attack )
 
 	if( abl == ABL_KIND_MON ){
 		long	n;
-		rate_t	rate;
 
 		n = get_lev( p, abl );
 		wpn_dam += DAM_MON_MUL * n;
 		if( n > 0 )
 			wpn_dam += DAM_MON_ADD;
-
-		if( p->kind == CHR_KIND_MBR ){
-			rate = calc_rate_abl_equip( p, ABL_KIND_MON );
-			dam = dam * rate / _100_PERCENT;
-		}
 	}
 
+	if( p->kind == CHR_KIND_MBR )
+		dam = dam * calc_rate_abl_equip( p, abl ) / _100_PERCENT;
+
 	/* FXͤä */
 
 	wpn_dam += p->fx_data.wpn_dam;
@@ -1644,7 +1643,6 @@ long	get_def( chr_t *p )
 	long	def;
 	rate_t	armor_def;
 	abl_kind_t	abl;
-	rate_t	rate;
 
 	if( p == NULL )
 		return 1;
@@ -1658,10 +1656,8 @@ long	get_def( chr_t *p )
 	def += calc_lev_to_val( get_lev( p, abl ), abl );
 	def /= 2;
 
-	if( p->kind == CHR_KIND_MBR ){
-		rate = calc_rate_abl_equip( p, abl );
-		def = def * rate / _100_PERCENT;
-	}
+	if( p->kind == CHR_KIND_MBR )
+		def = def * calc_rate_abl_equip( p, abl ) / _100_PERCENT;
 
 	armor_def = get_armor_def( p, abl );
 
@@ -1693,7 +1689,7 @@ abl_kind_t	get_def_abl( chr_t *p )
 
 	if( p->kind == CHR_KIND_MBR ){
 		item_t	*eq;
-		flg_item_abl	flg_abl;
+		bool_t	*flg_abl;
 
 		eq = get_mbr_item_asgn_equip( (mbr_t *)p );
 		if( eq == NULL )
@@ -1704,8 +1700,9 @@ abl_kind_t	get_def_abl( chr_t *p )
 
 		if( eq[EQUIP_KIND_WIELDING].tab.wpn == NULL )
 			return ABL_KIND_MON;
+
 		flg_abl = eq[EQUIP_KIND_WIELDING].tab.wpn->flg_abl;
-		if( chk_flg( flg_abl, FLG_ITEM_ABL_MON ) )
+		if( flg_abl[ABL_KIND_MON] )
 			return ABL_KIND_MON;
 		else
 			return ABL_KIND_FIG;
