@@ -86,6 +86,7 @@ bool_t	read_scroll_pow_up_armor_ac( chr_t *chr );
 bool_t	read_scroll_protect_armor( chr_t *chr );
 bool_t	read_scroll_remove_curse( chr_t *chr );
 bool_t	read_scroll_recall( void );
+void	read_scroll_nin( chr_t *chr, scroll_kind_t kind );
 bool_t	zap_stick( chr_t *chr, item_t *item );
 bool_t	fx_std( chr_t *chr, fx_kind_t fx_k );
 bool_t	set_fx_std( chr_t *chr, fx_kind_t fx_k );
@@ -137,8 +138,8 @@ bool_t	magic_armor(
 	rate_t armor_def, rate_t armor_crtcl, rate_t armor_ac
 );
 bool_t	fx_speed_up( chr_t *chr1, chr_t *chr2, long add, long turn );
-void	fx_energy_drain_all_mbr( void );
-bool_t	fx_energy_drain( chr_t *chr );
+void	fx_energy_drain_all_mbr( bool_t flg_set_max );
+bool_t	fx_energy_drain( chr_t *chr, bool_t flg_set_max );
 bool_t	fx_resi( chr_t *chr, fx_kind_t fx_k, long turn );
 bool_t	pow_up_resi( chr_t *chr, resi_kind_t resi );
 bool_t	pow_down_resi( chr_t *chr, resi_kind_t resi );
