@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.57 2004/07/30 14:29:27 bowkenken Exp $
-*****************************************************************/
+* $Id: gmain.c,v 1.60 2004/12/10 08:35:39 bowkenken Exp $
+***************************************************************/
 
 #include	<signal.h>
 
@@ -133,7 +133,9 @@ void	init_game( void )
 	init_tmenu();
 	init_auto_menu();
 	init_request();
+
 	init_mbr_formation();
+	init_spell_nin();
 
 	if( g_flg_debug )
 		set_flg_no_save( TRUE );
@@ -169,7 +171,7 @@ void	init_game( void )
 void	game_main( void )
 {
 	while( 1 ){
-		chk_key( TRUE );
+		chk_key( TRUE, TRUE );
 	}
 }
 
