@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.68 2004/07/29 13:40:49 bowkenken Exp $
-*****************************************************************/
+* $Id: item.h,v 1.73 2004/12/13 14:14:23 bowkenken Exp $
+***************************************************************/
 
 #ifndef	ITEM_H
 #define	ITEM_H
@@ -234,7 +234,7 @@
 #define	ACCE_PRICE_D	15000
 #define	ACCE_PRICE_E	10000
 
-/******************************************************************/
+/***************************************************************/
 
 /* ƥबѲǽ? */
 
@@ -246,6 +246,7 @@ typedef enum {
 
 /*  */
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	EQUIP_KIND_WIELDING,
 	EQUIP_KIND_SHIELD,
@@ -534,6 +535,14 @@ typedef enum {
 	SCROLL_KIND_PROTECT_ARMOR,
 	SCROLL_KIND_REMOVE_CURSE,
 	SCROLL_KIND_RECALL,
+	SCROLL_KIND_TYPHOON,
+	SCROLL_KIND_CONFLAGRATION,
+	SCROLL_KIND_EARTHQUAKE,
+	SCROLL_KIND_THUNDERCLOUD,
+	SCROLL_KIND_INUNDATION,
+	SCROLL_KIND_SUBSTITUTE,
+	SCROLL_KIND_BURNING_HANDS,
+	SCROLL_KIND_MIND_READING,
 	SCROLL_KIND_MAX_N,
 } scroll_kind_t;
 
@@ -873,7 +882,7 @@ typedef enum {
 	COIN_KIND_MAX_N,
 } coin_kind_t;
 
-/******************************************************************/
+/***************************************************************/
 
 
 typedef struct {
@@ -901,29 +910,6 @@ typedef unsigned long	flg_wpn_tab_t;
 #define	FLG_WPN_TAB_THROW	\
 		(FLG_WPN_TAB_ARW | FLG_WPN_TAB_NOT_SPEND)
 
-/* ǽ̵Υե饰 */
-
-typedef unsigned long	flg_item_abl;
-
-#define	FLG_ITEM_ABL_FIG	(1 << 0)
-#define	FLG_ITEM_ABL_MON	(1 << 1)
-#define	FLG_ITEM_ABL_HUN	(1 << 2)
-#define	FLG_ITEM_ABL_THI	(1 << 3)
-#define	FLG_ITEM_ABL_MAG	(1 << 4)
-#define	FLG_ITEM_ABL_SOR	(1 << 5)
-#define	FLG_ITEM_ABL_ENC	(1 << 6)
-#define	FLG_ITEM_ABL_SUM	(1 << 7)
-#define	FLG_ITEM_ABL_PRI	(1 << 8)
-#define	FLG_ITEM_ABL_SHA	(1 << 9)
-#define	FLG_ITEM_ABL_BAR	(1 << 10)
-#define	FLG_ITEM_ABL_NIN	(1 << 11)
-
-#define	FLG_ITEM_ABL_ALL_MAG	\
-		(FLG_ITEM_ABL_MAG | FLG_ITEM_ABL_SOR \
-		| FLG_ITEM_ABL_ENC | FLG_ITEM_ABL_SUM)
-#define	FLG_ITEM_ABL_MAG_SHA	\
-		(FLG_ITEM_ABL_ALL_MAG | FLG_ITEM_ABL_SHA)
-
 /* ƥΥե饰 */
 
 typedef unsigned long	flg_item_t;
@@ -1022,7 +1008,7 @@ typedef struct {
 	coin_kind_t	kind;
 } coin_t;
 
-/******************************************************************/
+/***************************************************************/
 /* ơ֥ */
 
 typedef struct {
@@ -1058,7 +1044,7 @@ typedef struct {
 	/* ե饰 */
 	flg_wpn_tab_t	flg;
 	/* ǽ̵Υե饰 */
-	flg_item_abl	flg_abl;
+	bool_t	flg_abl[ABL_KIND_MAX_N];
 
 	/* Υǡ */
 	attack_t	attack[WPN_ATTACK_MAX_N + 1];
@@ -1098,11 +1084,14 @@ typedef struct {
 	rate_t	rate;
 
 	/* ǽ̵Υե饰 */
-	flg_item_abl	flg_abl;
+	bool_t	flg_abl[ABL_KIND_MAX_N];
 
 	/* ƤΨ */
 	rate_t	rate_curse;
 
+	/* ݸƤե饰 */
+	bool_t	flg_protected;
+
 	/* ǽͽǡ */
 	modifier_t	modifier;
 } armor_tab_t;
@@ -1435,7 +1424,7 @@ typedef struct {
 	coin_kind_t	coin;
 } item_kind_dat_t;
 
-/******************************************************************/
+/***************************************************************/
 
 /* ƥ */
 
