@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-unix.c,v 1.1 2004/07/26 10:02:44 bowkenken Exp $
-*****************************************************************/
+* $Id: main-unix.c,v 1.3 2004/12/10 11:18:55 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -141,8 +141,10 @@ char	str_usage[] = {
 	"                             ON, OFF\n"
 	"  -m, --measure-clock=FLAG measure CLK_TCK:\n"
 	"                             ON, OFF\n"
+#if	0
 	"  -d, --debug=FLAG         set debug mode:\n"
 	"                             ON, OFF\n"
+#endif
 	"  -V, --version            display version and exit\n"
 	"  -h, --help               display this help and exit\n"
 };
