@@ -191,6 +191,8 @@ void	set_scroll_smooth( void );
 void	set_scroll_center( void );
 char	*cb_menu_actual_fighting( menu_t **pp, menu_t **dflt );
 char	*cb_menu_space_select( menu_t **pp, menu_t **dflt );
+char	*cb_menu_window( menu_t **pp, menu_t **dflt );
+char	*cb_menu_redraw_every_turn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt );
@@ -271,7 +273,7 @@ bool_t	next_pos_mnstr_sub( long *dx, long *dy, long d );
 bool_t	next_pos_all( long d );
 void	wait_key( bool_t flg_can_move_crsr );
 void	wait_key_ex( bool_t flg_exec_key, bool_t flg_can_move_crsr );
-long	chk_key( bool_t flg_chk_menu );
+long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu );
 void	chk_dup_accel_key( void );
 void	chk_dup_accel_key_init( void );
 bool_t	chk_dup_accel_key_main( menu_t *ls );
@@ -303,6 +305,7 @@ flg_scroll_t	get_flg_scroll( void );
 flg_scroll_t	set_flg_scroll( flg_scroll_t flg );
 bool_t	get_flg_space_select( void );
 bool_t	set_flg_space_select( bool_t flg );
+bool_t	*get_ls_flg_srch( void );
 
 #ifdef __cplusplus
 }
