@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu-tab.h,v 1.1 2004/07/26 10:02:44 bowkenken Exp $
-*****************************************************************/
+* $Id: menu-tab.h,v 1.3 2004/12/23 06:12:38 bowkenken Exp $
+***************************************************************/
 
 #ifndef	MENU_TAB_H
 #define	MENU_TAB_H
@@ -673,9 +673,27 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Multi Message",
+		"/Misc/Config/Window",
+		"<Branch>",
+		'W',
+		"",
+		N_MSG_MENU_WINDOW, "",
+		cb_menu_window, NULL,
+		FLG_NULL,
+	},
+	{
+		"/Misc/Config/Window/Redraw Every Turn",
 		"<CheckItem>",
-		'G',
+		'D',
+		"",
+		N_MSG_MENU_REDRAW_EVERY_TURN, "",
+		cb_menu_redraw_every_turn, NULL,
+		FLG_NULL,
+	},
+	{
+		"/Misc/Config/Window/Multi Message",
+		"<CheckItem>",
+		'M',
 		"",
 		N_MSG_MENU_MUL_MSG_LINE, "",
 		cb_menu_mul_msg_line, NULL,
