@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.h,v 1.23 2004/07/12 17:09:35 bowkenken Exp $
-*****************************************************************/
+* $Id: menu.h,v 1.26 2004/12/06 07:00:15 bowkenken Exp $
+***************************************************************/
 
 #ifndef	MENU_H
 #define	MENU_H
@@ -159,12 +159,19 @@ typedef struct menu_t {
 typedef struct {
 	/* ȥ */
 	char	*ttl;
+
 	/* Υ˥塼Υꥹ */
 	menu_t	*ls[MENU_MAX_N_PER_PAGE + 1];
+
 	/* 򤵤Ƥܤֹ */
 	long	sel_n, prev_sel_n;
+
+	/* ڡ */
+	long	page_sel_n, page_max_n;
+
 	/* ƬǽڡǤЯΥե饰 */
 	bool_t	flg_min_page, flg_max_page;
+
 	/* ե饰 */
 	bool_t	flg_redraw;
 } draw_menu_t;
@@ -191,6 +198,7 @@ typedef enum {
 typedef enum {
 	MENU_NUM_MIN,
 	MENU_NUM_MAX,
+	MENU_NUM_CLR,
 	MENU_NUM_OK,
 	MENU_NUM_MAX_N
 } menu_num_t;
