@@ -12,6 +12,8 @@ long	randm( long n );
 long	randm_sub( long n );
 bool_t	rate_randm( rate_t rate );
 bool_t	per_randm( long per );
+bool_t	chk_ver_old( const ver_t *ver, long mjr, long mnr, long pat );
+bool_t	chk_ver_match( const ver_t *ver, long mjr, long mnr, long pat );
 rate_t	modified_rate( rate_t rate, long n );
 long	str_len_draw( const char *s );
 long	str_len_draw_english( const char *s );
