@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.25 2004/07/29 07:05:00 bowkenken Exp $
-*****************************************************************/
+* $Id: misc.c,v 1.28 2004/12/14 08:52:04 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 #include	"misc.h"
@@ -140,8 +140,8 @@ long	randm_sub( long n )
 	rand_seed += 598393;
 	a = (rand_seed & 0xffff0000) >> 16;
 	rand_seed = ((rand_seed & 0x0000ffff) << 16) + a;
-	rand_seed = labs( rand_seed );
 	rand_seed += 379;
+	rand_seed = labs( rand_seed );
 
 	if( n > 0 )
 		return( rand_seed % n );
@@ -165,6 +165,48 @@ bool_t	per_randm( long per )
 
 /**/
 
+bool_t	chk_ver_old( const ver_t *ver, long mjr, long mnr, long pat )
+{
+	if( ver == NULL )
+		return FALSE;
+
+	if( ver->mjr > mjr )
+		return FALSE;
+	if( ver->mjr < mjr )
+		return TRUE;
+
+	if( ver->mnr > mnr )
+		return FALSE;
+	if( ver->mnr < mnr )
+		return TRUE;
+
+	if( ver->pat > pat )
+		return FALSE;
+	if( ver->pat < pat )
+		return TRUE;
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	chk_ver_match( const ver_t *ver, long mjr, long mnr, long pat )
+{
+	if( ver == NULL )
+		return FALSE;
+
+	if( ver->mjr != mjr )
+		return FALSE;
+	if( ver->mnr != mnr )
+		return FALSE;
+	if( ver->pat != pat )
+		return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
 rate_t	modified_rate( rate_t rate, long n )
 {
 	if( n >= +1 )
