@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.h,v 1.10 2004/06/30 13:20:45 bowkenken Exp $
-*****************************************************************/
+* $Id: misc.h,v 1.12 2004/12/08 01:50:21 bowkenken Exp $
+***************************************************************/
 
 #ifndef	MISC_H
 #define	MISC_H
@@ -79,6 +79,7 @@ typedef struct {
 /*  */
 
 typedef long	gold_t;
+#define	GOLD_MAX	999999999
 
 /* С */
 
