@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-act.c,v 1.1 2004/07/26 10:02:44 bowkenken Exp $
-*****************************************************************/
+* $Id: mnstr-act.c,v 1.6 2004/12/23 07:24:08 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 #include	"misc.h"
@@ -85,8 +85,9 @@
 #define	TOWNER_ENTER_DOOR_R	3
 #define	TOWNER_CANCEL_DOOR_RATE	10
 
-#define	TOWNER_EXIT_DOOR_RATE_DAY	10
-#define	TOWNER_EXIT_DOOR_RATE_NIGHT	2
+#define	TOWNER_EXIT_DOOR_RATE	((rate_t)2)
+#define	TOWNER_EXIT_DOOR_RATE_DAY	((rate_t)100)
+#define	TOWNER_EXIT_DOOR_RATE_NIGHT	((rate_t)1)
 
 /*  */
 
@@ -224,6 +225,8 @@ void	set_act_towner_exit_door( mnstr_t *p )
 	if( p->work.enter_door == NULL )
 		return;
 
+	if( !rate_randm( TOWNER_EXIT_DOOR_RATE ) )
+		return;
 	if( chk_night() ){
 		if( !rate_randm( TOWNER_EXIT_DOOR_RATE_NIGHT ) ){
 			return;
@@ -241,6 +244,11 @@ void	set_act_towner_exit_door( mnstr_t *p )
 	if( get_shop_n( dr->mnr ) == SHOP_N_BAR ){
 		long	i, max_n;
 
+		if( clip_pos( p->x, p->y ) ){
+			clr_map_chr( p );
+			draw_chr( p );
+		}
+
 		/* ǿʧ */
 
 		max_n = roll_dice( 5, FALSE );
@@ -249,7 +257,7 @@ void	set_act_towner_exit_door( mnstr_t *p )
 		}
 	}
 
-	put_chr( p, dr->x, dr->y, FALSE );
+	put_chr( p, dr->x, dr->y );
 	p->work.enter_door = NULL;
 }
 
@@ -337,7 +345,7 @@ bool_t	set_act_rescue_trgt( mnstr_t *p )
 
 /**/
 
-/******************************************************************/
+/***************************************************************/
 
 /*  */
 /* ɥ饴 */
