@@ -7,12 +7,17 @@ extern "C" {
 void	init_mnstr( void );
 void	reset_mnstr( void );
 void	new_mnstr( mnstr_t *mnstr );
-mnstr_t	*make_mnstr_rand( long x, long y, long dun_lev );
+mnstr_t	*make_mnstr_rand( long x, long y, bool_t flg_fix_pos, long dun_lev );
 mnstr_t	*make_mnstr(
-	long x, long y, long dun_lev, mnstr_kind_t mnstr_kind
+	long x, long y, bool_t flg_fix_pos,
+	long dun_lev,
+	mnstr_kind_t mnstr_kind
 );
 mnstr_t	*make_mnstr_alloc(
-	mnstr_t *p, long x, long y, long dun_lev, mnstr_kind_t mnstr_kind
+	mnstr_t *p,
+	long x, long y, bool_t flg_fix_pos,
+	long dun_lev,
+	mnstr_kind_t mnstr_kind
 );
 bool_t	make_mnstr_special( long dun_lev, mnstr_t *p );
 mnstr_t	*make_npc_rand( long x, long y, long dun_lev );
@@ -35,6 +40,8 @@ void	set_flg_find_all_mnstr( void );
 bool_t	set_flg_find_mnstr( mnstr_t *p );
 void	chk_trap_all_mnstr( void );
 void	die_mnstr( mnstr_t *p );
+bool_t	chk_die_boss( mnstr_t *p );
+void	die_boss( mnstr_t *m );
 void	mnstr_drop_gold( mnstr_t *p );
 void	mnstr_drop_item( mnstr_t *p );
 void	set_find_all_mnstr( void );
