@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.147 2004/07/30 16:02:14 bowkenken Exp $
-*****************************************************************/
+* $Id: mnstr.c,v 1.154 2004/12/25 23:35:24 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -75,15 +75,6 @@
 
 /**/
 
-static mnstr_t	mnstr_buf[MNSTR_MAX_N];
-static mnstr_t	mnstr_used, mnstr_free;
-
-/**/
-
-#include	"mnstr-tab.h"
-
-/**/
-
 #define	GARGOYLE_STATUE_N	3
 
 #define	MNSTR_GOLD_MUL_N	12
@@ -91,6 +82,18 @@ static mnstr_t	mnstr_used, mnstr_free;
 
 #define	TOWNER_AVE_DUN_LEV	48
 
+#define	GROUP_RATE_DENOMINATOR	10
+#define	GROUP_RATE_BASE	50
+
+/**/
+
+static mnstr_t	mnstr_buf[MNSTR_MAX_N];
+static mnstr_t	mnstr_used, mnstr_free;
+
+/**/
+
+#include	"mnstr-tab.h"
+
 /**/
 
 void	init_mnstr( void )
@@ -289,7 +292,7 @@ void	new_mnstr( mnstr_t *mnstr )
 
 /**/
 
-mnstr_t	*make_mnstr_rand( long x, long y, long dun_lev )
+mnstr_t	*make_mnstr_rand( long x, long y, bool_t flg_fix_pos, long dun_lev )
 {
 	mnstr_tab_t	*tab;
 	mnstr_t	*p;
@@ -306,17 +309,18 @@ mnstr_t	*make_mnstr_rand( long x, long y, long dun_lev )
 	if( !can_move_mnstr_tab( tab, x, y ) )
 		return NULL;
 
-	p = make_mnstr( x, y, dun_lev, tab->mnstr_kind );
+	p = make_mnstr( x, y, flg_fix_pos, dun_lev, tab->mnstr_kind );
 
 	group = roll_dice( tab->group, TRUE );
-	for( i = 0; i < tab->group - 1; i++ ){
+	for( i = 1; i < tab->group; i++ ){
 		long	nx, ny;
 		mnstr_t	*pp;
 
 		for( j = LOOP_MAX_100; j > 0; j-- ){
 			nx = x + (randm( 10 + 1 + 10 ) - 10);
 			ny = y + (randm( 10 + 1 + 10 ) - 10);
-			pp = make_mnstr( nx, ny, dun_lev, tab->mnstr_kind );
+			pp = make_mnstr( nx, ny, flg_fix_pos,
+					dun_lev, tab->mnstr_kind );
 			if( pp != NULL )
 				break;
 		}
@@ -328,7 +332,9 @@ mnstr_t	*make_mnstr_rand( long x, long y, long dun_lev )
 /**/
 
 mnstr_t	*make_mnstr(
-	long x, long y, long dun_lev, mnstr_kind_t mnstr_kind
+	long x, long y, bool_t flg_fix_pos,
+	long dun_lev,
+	mnstr_kind_t mnstr_kind
 )
 {
 	mnstr_t	*p;
@@ -340,7 +346,8 @@ mnstr_t	*make_mnstr(
 
 	new_mnstr( p );
 
-	if( make_mnstr_alloc( p, x, y, dun_lev, mnstr_kind ) == NULL ){
+	if( make_mnstr_alloc( p, x, y, flg_fix_pos, dun_lev, mnstr_kind )
+			== NULL ){
 		die_chr( p, FALSE, FALSE, TRUE );
 		return NULL;
 	}
@@ -351,7 +358,10 @@ mnstr_t	*make_mnstr(
 /**/
 
 mnstr_t	*make_mnstr_alloc(
-	mnstr_t *p, long x, long y, long dun_lev, mnstr_kind_t mnstr_kind
+	mnstr_t *p,
+	long x, long y, bool_t flg_fix_pos,
+	long dun_lev,
+	mnstr_kind_t mnstr_kind
 )
 {
 	long	i;
@@ -369,15 +379,15 @@ mnstr_t	*make_mnstr_alloc(
 	if( tab == NULL )
 		return NULL;
 
-	if( clip_pos( x, y ) )
+	if( clip_pos( x, y ) && flg_fix_pos )
 		if( !can_move_mnstr_tab( tab, x, y ) )
 			return NULL;
 
 	new_mnstr( p );
 
 	strncpy( p->name, tab->name, MNSTR_NAME_MAX_LEN );
-	p->x = x;
-	p->y = y;
+	p->x = MAP_DEL_X;
+	p->y = MAP_DEL_Y;
 	p->pre_x = p->x;
 	p->pre_y = p->y;
 	p->dx = tab->dx;
@@ -394,10 +404,20 @@ mnstr_t	*make_mnstr_alloc(
 	p->move = tab->move;
 	for( i = 0; i < ABL_KIND_MAX_N; i++ ){
 		long	lev;
+		long	group_denomi;
+		rate_t	group_rate;
 
 		lev = calc_mnstr_abl_lev( dun_lev,
 				tab->abl_lev_rate[i] );
 
+		/* οǥ٥ */
+
+		group_denomi = (tab->group + GROUP_RATE_DENOMINATOR - 1)
+				/ GROUP_RATE_DENOMINATOR;
+		group_rate = (_100_PERCENT - GROUP_RATE_BASE) / group_denomi
+				+ GROUP_RATE_BASE;
+		lev = lev * group_rate / _100_PERCENT;
+
 		p->abl.lev[i].n = lev;
 		p->abl.lev[i].max = lev;
 		p->abl.lev[i].add = 0;
@@ -456,11 +476,11 @@ mnstr_t	*make_mnstr_alloc(
 	else
 		p->flg_map |= FLG_MAP_CHR_NPC;
 
-	set_map_chr( p );
-
 	if( !make_mnstr_special( dun_lev, p ) )
 		return NULL;
 
+	put_chr( p, x, y );
+
 	return p;
 }
 
@@ -487,7 +507,8 @@ bool_t	make_mnstr_special( long dun_lev, mnstr_t *p )
 		if( link_n >= GIGANTIC_CENTIPEDE_LINK_N )
 			break;
 
-		p2 = make_mnstr( p->x, p->y + 1, dun_lev, p->mnstr_kind );
+		p2 = make_mnstr( p->x, p->y + 1, FALSE,
+				dun_lev, p->mnstr_kind );
 		if( p2 == NULL )
 			break;
 		mark_mnstr( p2, p, DIST_NEAR );
@@ -556,7 +577,7 @@ mnstr_t	*make_npc_rand( long x, long y, long dun_lev )
 	if( dun_lev < 1 )
 		dun_lev = 1;
 
-	return make_mnstr( x, y, dun_lev, kind );
+	return make_mnstr( x, y, FALSE, dun_lev, kind );
 }
 
 /**/
@@ -649,7 +670,9 @@ bool_t	chk_can_act_mnstr( mnstr_t *p )
 	if( chk_flg_or( p->stat,
 			FLG_STAT_NOT_EXIST | FLG_STAT_DEAD
 			| FLG_STAT_STONE | FLG_STAT_PARALYZE
-			| FLG_STAT_SLEEP | FLG_STAT_FAINT ) ){
+			| FLG_STAT_SLEEP | FLG_STAT_FAINT
+			| FLG_STAT_IRON_BODY
+			) ){
 		return FALSE;
 	}
 
@@ -1025,7 +1048,7 @@ bool_t	increase_mnstr( mnstr_t *p )
 	nx = p->x + (randm( 3 ) - 1);
 	ny = p->y + (randm( 3 ) - 1);
 
-	new_mnstr = make_mnstr( nx, ny, dun->lev, p->mnstr_kind );
+	new_mnstr = make_mnstr( nx, ny, FALSE, dun->lev, p->mnstr_kind );
 	if( new_mnstr == NULL )
 		return FALSE;
 
@@ -1199,6 +1222,54 @@ void	die_mnstr( mnstr_t *p )
 
 /**/
 
+bool_t	chk_die_boss( mnstr_t *p )
+{
+	if( p == NULL )
+		return FALSE;
+	if( p->kind != CHR_KIND_MNSTR )
+		return FALSE;
+	if( p->mnstr_tab == NULL )
+		return FALSE;
+	if( !(p->mnstr_tab->flg_boss) )
+		return FALSE;
+
+	die_boss( p );
+
+	return TRUE;
+}
+
+/**/
+
+void	die_boss( mnstr_t *m )
+{
+	long	boss_n;
+	mnstr_t	*head, *p, *pp;
+
+	if( m == NULL )
+		return;
+
+	boss_n = 0;
+
+	head = &mnstr_used;
+	for( p = head->next->next; p != NULL; p = p->next ){
+		pp = p->prev;
+		if( pp == head )
+			break;
+
+		if( pp->mnstr_tab != NULL ){
+			if( pp->mnstr_tab->flg_boss ){
+				boss_n++;
+			}
+		}
+	}
+
+	if( boss_n <= 1 ){
+		make_stairs( m->x, m->y, FACE_MJR_STAIRS_DOWN );
+	}
+}
+
+/**/
+
 void	mnstr_drop_gold( mnstr_t *p )
 {
 	long	n;
@@ -1601,7 +1672,7 @@ void	exp_chr_mnstr( chr_t *chr, long exp, bool_t flg_print_lev )
 
 	chr->abl.exp[left_k].n += left_exp;
 
-	chk_lev_up( chr, flg_print_lev );
+	chk_lev_up( chr, FALSE, flg_print_lev );
 }
 
 /**/
