@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.142 2004/07/31 07:27:27 bowkenken Exp $
-*****************************************************************/
+* $Id: party.c,v 1.156 2004/12/25 03:14:04 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -147,13 +147,13 @@ static rate_t	resi_init[MAIN_RACE_MAX_N][RESI_KIND_MAX_N] = {
 /* MAIN_RACE_HUMAN */
 	{   100, 100, 100, 100, 100, 100, 100, 100, 100 },
 /* MAIN_RACE_HALF_ELF */
-	{    90,  90,  90, 100, 100, 100, 100, 100, 100 },
+	{    90,  90,  90, 110, 110, 110, 110, 100, 100 },
 /* MAIN_RACE_ELF */
-	{    80,  80,  80, 100, 100, 150, 100, 100, 100 },
+	{    80,  80,  80, 120, 120, 120, 120, 100, 100 },
 /* MAIN_RACE_DWARF */
-	{   150, 150, 150, 100, 100, 100, 100, 100, 200 },
+	{   120, 120, 120,  80,  80,  80, 120, 100, 200 },
 /* MAIN_RACE_VIVID */
-	{    70,  70,  70, 100, 100, 200, 100, 100, 100 },
+	{    90,  90,  90, 100, 100, 200, 100, 100, 100 },
 };
 
 static stomach_t	ave_stomach[MAIN_RACE_MAX_N] = {
@@ -477,7 +477,7 @@ void	init_party_debug( void )
 	race.sub = SUB_RACE_NULL;
 	strncpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
-			MALE, CLASS_N_BARD, 4 );
+			MALE, CLASS_N_THIEF, 4 );
 
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
@@ -606,18 +606,13 @@ void	init_party_debug( void )
 
 	/* armor */
 
-	i = 0;
-	sub_kind.armor = ARMOR_KIND_SALLET;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_ARMOR, &sub_kind,
-			TRUE, FALSE, TRUE );
-
 	i = 1;
 	sub_kind.armor = ARMOR_KIND_SALLET;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_ARMOR, &sub_kind,
 			TRUE, FALSE, TRUE );
 
 	i = 0;
-	sub_kind.armor = ARMOR_KIND_CHAIN_MAIL;
+	sub_kind.armor = ARMOR_KIND_MITHRIL_CHAIN;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_ARMOR, &sub_kind,
 			TRUE, FALSE, TRUE );
 
@@ -649,6 +644,46 @@ void	init_party_debug( void )
 	/* scroll */
 
 	i = 0;
+	sub_kind.scroll = SCROLL_KIND_TYPHOON;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+
+	i = 0;
+	sub_kind.scroll = SCROLL_KIND_CONFLAGRATION;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 0;
+	sub_kind.scroll = SCROLL_KIND_EARTHQUAKE;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 0;
+	sub_kind.scroll = SCROLL_KIND_THUNDERCLOUD;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 0;
+	sub_kind.scroll = SCROLL_KIND_INUNDATION;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 0;
+	sub_kind.scroll = SCROLL_KIND_SUBSTITUTE;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 0;
+	sub_kind.scroll = SCROLL_KIND_BURNING_HANDS;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 0;
+	sub_kind.scroll = SCROLL_KIND_MIND_READING;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 1;
 	sub_kind.scroll = SCROLL_KIND_RECALL;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
 			FALSE, FALSE, FALSE );
@@ -685,27 +720,27 @@ void	init_party_debug( void )
 
 	/* potion */
 
-	i = 0;
+	i = 1;
 	sub_kind.potion = POTION_KIND_RESI_PHYS;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			FALSE, FALSE, FALSE );
 
-	i = 0;
+	i = 1;
 	sub_kind.potion = POTION_KIND_STRENGTH;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			TRUE, FALSE, FALSE );
 
-	i = 0;
+	i = 1;
 	sub_kind.potion = POTION_KIND_DULLNESS;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			TRUE, FALSE, FALSE );
 
-	i = 0;
+	i = 1;
 	sub_kind.potion = POTION_KIND_POISON;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			TRUE, FALSE, FALSE );
 
-	i = 0;
+	i = 1;
 	sub_kind.potion = POTION_KIND_FLY;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			TRUE, FALSE, FALSE );
@@ -826,7 +861,7 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_TOBACCO, &sub_kind,
 			TRUE, FALSE, FALSE );
 
-	i = 0;
+	i = 2;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_CHEST, NULL,
 			TRUE, FALSE, FALSE );
 
@@ -1225,7 +1260,24 @@ void	new_mbr(
 
 	init_auto_mark_mbr( mbr->ls_mbr_n );
 
-	exp_chr( mbr, DFLT_EXP, FALSE, FALSE );
+	exp_chr( mbr, DFLT_EXP, TRUE, FALSE, FALSE );
+}
+
+/**/
+
+bool_t	reset_mbr_resi( mbr_t *mbr )
+{
+	resi_kind_t	k;
+
+	if( mbr == NULL )
+		return FALSE;
+	if( mbr->kind != CHR_KIND_MBR )
+		return FALSE;
+
+	for( k = 0; k < RESI_KIND_MAX_N; k++ )
+		mbr->resi[k].max = resi_init[mbr->race.main][k];
+
+	return TRUE;
 }
 
 /**/
@@ -1290,7 +1342,7 @@ void	set_mbr_dir( void )
 
 /**/
 
-void	appear_party( bool_t flg_clr_map )
+void	appear_party( void )
 {
 	bool_t	flg_force = TRUE;
 	long	i, n;
@@ -1302,8 +1354,7 @@ void	appear_party( bool_t flg_clr_map )
 
 	release_all_mbr();
 
-	if( flg_clr_map )
-		clr_map_all_mbr();
+	clr_map_all_mbr();
 
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		party.square.x = 1 + randm( MAP_MAX_X - 2);
@@ -1327,27 +1378,32 @@ void	appear_party( bool_t flg_clr_map )
 			party.mbr[n]->pre_x = nx;
 			party.mbr[n]->pre_y = ny;
 
-			if( !can_move_chr( party.mbr[n], nx, ny ) )
-				break;	/* ֤˰ưʤ */
+			if( !can_move_chr( party.mbr[n], nx, ny ) ){
+				/* ֤˰ưʤ */
+				break;
+			}
 		}
 		if( n >= MBR_MAX_N ){
+			/* ư褿 */
 			flg_force = FALSE;
-			break;	/* ư褿 */
+			break;
 		}
 	}
 
 	if( flg_force ){
 		for( n = 0; n < MBR_MAX_N; n++ ){
+			party.mbr[n]->x = MAP_DEL_X;
+			party.mbr[n]->y = MAP_DEL_Y;
+
 			put_chr( party.mbr[n],
 					MAP_MAX_X / 2,
-					MAP_MAX_Y / 2,
-					FALSE );
+					MAP_MAX_Y / 2 );
 		}
 	}
 
 	set_map_all_mbr();
 
-	appear_all_pet( flg_clr_map );
+	appear_all_pet();
 }
 
 /**/
@@ -1393,14 +1449,8 @@ void	move_phase_party( void )
 {
 	long	i;
 
-	for( i = 0; i < MBR_MAX_N; i++ ){
-		if( chk_flg_or( party.mbr[i]->stat,
-				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
-			continue;
-		}
-
+	for( i = 0; i < MBR_MAX_N; i++ )
 		move_phase_chr( party.mbr[i] );
-	}
 
 	draw_party();
 }
@@ -1412,11 +1462,6 @@ void	act_phase_party( void )
 	long	i;
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
-		if( chk_flg_or( party.mbr[i]->stat,
-				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
-			continue;
-		}
-
 		act_phase_chr( party.mbr[i] );
 		set_modifier( party.mbr[i] );
 	}
@@ -1554,7 +1599,7 @@ void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over )
 	if( i >= MBR_MAX_N ){
 		print_msg( FLG_MSG_NO_MORE_PREV, MSG_S, MSG_GAME_OVER );
 		while( 1 ){
-			switch( get_key( FALSE ) ){
+			switch( get_key( TRUE ) ){
 			case 'C' - '@':
 			case 'Q' - '@':
 				exit_game( EXIT_SUCCESS );
@@ -1573,7 +1618,9 @@ bool_t	chk_can_act_mbr( mbr_t *p )
 	if( chk_flg_or( p->stat,
 			FLG_STAT_NOT_EXIST | FLG_STAT_DEAD
 			| FLG_STAT_STONE | FLG_STAT_PARALYZE
-			| FLG_STAT_SLEEP | FLG_STAT_FAINT ) ){
+			| FLG_STAT_SLEEP | FLG_STAT_FAINT
+			| FLG_STAT_IRON_BODY
+			) ){
 		return FALSE;
 	}
 
@@ -1671,7 +1718,7 @@ void	join_mbr( long ls_mbr_n, long mbr_n )
 
 	x = party.square.x + party.square.chr_pos[mbr_n].x;
 	y = party.square.y + party.square.chr_pos[mbr_n].y;
-	put_chr( party.mbr[mbr_n], x, y, TRUE );
+	put_chr( party.mbr[mbr_n], x, y );
 }
 
 /**/
@@ -1696,23 +1743,25 @@ void	not_join_mbr( long ls_mbr_n, long mbr_n )
 void	collect_gold( mbr_t *mbr )
 {
 	bool_t	flg_force;
-	gold_t	gold;
+	gold_t	gold, res_price;
 	long	i;
 
 	if( mbr == NULL )
 		return;
 
-	flg_force = FALSE;
-	for( i = 0; i < MBR_MAX_N; i++ ){
-		if( !chk_flg( party.mbr[i]->stat, FLG_STAT_DEAD ) ){
-			/* ѤGOLDϵݽʤ */
+	/* Ѥ GOLD ϵݽʤ */
 
-			flg_force = TRUE;
-			break;
-		}
+	res_price = get_price_temple_resurrection( mbr );
+	flg_force = FALSE;
+	if( chk_flg( mbr->stat, FLG_STAT_DEAD )
+			&& (get_chr_gold( mbr ) < res_price)
+			&& (mbr->fx_data.friend_turn > 0) ){
+		flg_force = TRUE;
 	}
 
-	if( party.mbr[i]->fx_data.friend_turn > 0 ){
+	/* GOLD Τ */
+
+	if( mbr->fx_data.friend_turn > 0 ){
 		if( !flg_force ){
 			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
 					mbr->name );
@@ -1725,6 +1774,8 @@ void	collect_gold( mbr_t *mbr )
 		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
+		/* GOLD Τ */
+
 		if( party.mbr[i]->fx_data.friend_turn > 0 ){
 			if( !flg_force ){
 				print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
@@ -1733,11 +1784,11 @@ void	collect_gold( mbr_t *mbr )
 			}
 		}
 
-		gold += party.mbr[i]->gold;
-		party.mbr[i]->gold = 0;
+		gold += get_chr_gold( party.mbr[i] );
+		add_chr_gold( party.mbr[i], - party.mbr[i]->gold );
 	}
 
-	mbr->gold = gold;
+	add_chr_gold( mbr, gold );
 
 	print_msg( FLG_NULL, MSG_COLLECT_GOLD, mbr->name, gold );
 }
@@ -1750,11 +1801,11 @@ void	divide_gold( void )
 	gold_t	sum, gold;
 	long	i, n, mod_n;
 
+	/* Ѥ GOLD ϵݽʤ */
+
 	flg_force = FALSE;
 	for( i = 0; i < MBR_MAX_N; i++ ){
-		if( !chk_flg( party.mbr[i]->stat, FLG_STAT_DEAD ) ){
-			/* ѤGOLDϵݽʤ */
-
+		if( chk_flg( party.mbr[i]->stat, FLG_STAT_DEAD ) ){
 			flg_force = TRUE;
 			break;
 		}
@@ -1767,6 +1818,8 @@ void	divide_gold( void )
 		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
+		/* GOLD Τ */
+
 		if( party.mbr[i]->fx_data.friend_turn > 0 ){
 			if( !flg_force ){
 				print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
@@ -1775,8 +1828,8 @@ void	divide_gold( void )
 			}
 		}
 
-		sum += party.mbr[i]->gold;
-		party.mbr[i]->gold = 0;
+		sum += get_chr_gold( party.mbr[i] );
+		add_chr_gold( party.mbr[i], - party.mbr[i]->gold );
 		n++;
 		if( per_randm( n ) )
 			mod_n = i;
@@ -1792,22 +1845,46 @@ void	divide_gold( void )
 			if( !flg_force )
 				continue;
 
-		party.mbr[i]->gold += gold;
+		add_chr_gold( party.mbr[i], gold );
 		sum -= gold;
 	}
 
-	party.mbr[mod_n]->gold += sum;
+	add_chr_gold( party.mbr[mod_n], sum );
 
 	print_msg( FLG_NULL, MSG_DIVIDE_GOLD, gold );
 }
 
 /**/
 
+gold_t	get_party_gold( void )
+{
+	gold_t	gold;
+	long	i;
+
+	gold = 0;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		gold += get_chr_gold( party.mbr[i] );
+	}
+
+	return gold;
+}
+
+/**/
+
 void	add_party_gold( gold_t gold )
 {
 	gold_t	div_gold;
 	long	i, n, mod_n;
 
+	if( gold < 0 ){
+		sub_party_gold( -gold );
+		return;
+	}
+
 	mod_n = 0;
 	n = 0;
 	for( i = 0; i < MBR_MAX_N; i++ ){
@@ -1831,7 +1908,7 @@ void	add_party_gold( gold_t gold )
 		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
-		party.mbr[i]->gold += div_gold;
+		add_chr_gold( party.mbr[i], div_gold );
 		gold -= div_gold;
 	}
 
@@ -1840,7 +1917,63 @@ void	add_party_gold( gold_t gold )
 
 /**/
 
-void	exp_party( long exp, bool_t flg_draw )
+gold_t	sub_party_gold( gold_t gold )
+{
+	gold_t	div_gold, sub_gold;
+	long	i, n;
+
+	if( gold < 0 ){
+		add_party_gold( -gold );
+		return (gold_t)0;
+	}
+
+	n = 0;
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		n++;
+	}
+	if( n <= 0 )
+		return gold;
+
+	curs_attrset_chr( get_mbr_randm( MAP_DEL_X, MAP_DEL_Y ),
+			-1, FALSE );
+	print_msg( FLG_NULL, MSG_SUB_PARTY_GOLD, gold );
+	curs_attrset_dflt();
+
+	div_gold = gold / n;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		/* 괪 (div_gold) */
+		sub_gold = min_l( get_chr_gold( party.mbr[i] ),
+				div_gold );
+
+		add_chr_gold( party.mbr[i], -sub_gold );
+		gold -= sub_gold;
+	}
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		/* Ƭ鸺餻餹 (gold) */
+		sub_gold = min_l( get_chr_gold( party.mbr[i] ),
+				gold );
+
+		add_chr_gold( party.mbr[i], -sub_gold );
+		gold -= sub_gold;
+	}
+
+	return gold;
+}
+
+/**/
+
+void	exp_party( long exp, bool_t flg_set_max, bool_t flg_draw )
 {
 	party_t	*pty = get_party();
 	pet_t	**pet = get_party_pet();
@@ -1882,9 +2015,11 @@ void	exp_party( long exp, bool_t flg_draw )
 
 		if( mod_n == i ){
 			exp_chr( pty->mbr[i], exp_add + exp_mod,
+					flg_set_max,
 					FALSE, TRUE );
 		} else {
 			exp_chr( pty->mbr[i], exp_add,
+					flg_set_max,
 					FALSE, TRUE );
 		}
 	}
@@ -1897,7 +2032,7 @@ void	exp_party( long exp, bool_t flg_draw )
 		if( chk_flg_or( pet[i]->stat, flg ) )
 			continue;
 
-		exp_chr( pet[i], exp_add, FALSE, TRUE );
+		exp_chr( pet[i], exp_add, flg_set_max, FALSE, TRUE );
 	}
 }
 
