@@ -9,10 +9,11 @@ void	init_pet_debug( void );
 pet_t	*make_pet( long dun_lev, pet_kind_t pet_kind, chr_t *owner );
 pet_t	*make_pet_alloc( pet_t *p, long dun_lev, pet_kind_t pet_kind );
 void	new_pet( pet_t *pet );
+bool_t	reset_pet_resi( pet_t *pet );
 void	clr_map_all_pet( void );
 void	set_map_all_pet( void );
-void	appear_all_pet( bool_t flg_clr_map );
-void	appear_pet( pet_t *pet, bool_t flg_clr_map );
+void	appear_all_pet( void );
+void	appear_pet( pet_t *pet );
 void	move_phase_all_pet( void );
 void	act_phase_all_pet( void );
 void	set_act_pet_std( pet_t *p );
