@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.42 2004/07/28 07:05:57 bowkenken Exp $
-*****************************************************************/
+* $Id: pet.c,v 1.46 2004/12/08 04:56:17 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 #include	"misc.h"
@@ -157,7 +157,8 @@ pet_t	*make_pet_alloc( pet_t *p, long dun_lev, pet_kind_t pet_kind )
 
 	new_pet( p );
 
-	m = make_mnstr_alloc( p, MAP_DEL_X, MAP_DEL_Y, dun_lev, pet_kind );
+	m = make_mnstr_alloc( p, MAP_DEL_X, MAP_DEL_Y, FALSE,
+			dun_lev, pet_kind );
 	if( m == NULL )
 		return NULL;
 
@@ -183,6 +184,26 @@ void	new_pet( pet_t *pet )
 
 /**/
 
+bool_t	reset_pet_resi( pet_t *pet )
+{
+	resi_kind_t	k;
+
+	if( pet == NULL )
+		return FALSE;
+	if( !is_pet( pet ) )
+		return FALSE;
+
+	if( pet->mnstr_tab == NULL )
+		return FALSE;
+
+	for( k = 0; k < RESI_KIND_MAX_N; k++ )
+		pet->resi[k].max = pet->mnstr_tab->resi[k];
+
+	return TRUE;
+}
+
+/**/
+
 void	clr_map_all_pet( void )
 {
 	long	i;
@@ -203,7 +224,7 @@ void	set_map_all_pet( void )
 
 /**/
 
-void	appear_all_pet( bool_t flg_clr_map )
+void	appear_all_pet( void )
 {
 	long	i;
 
@@ -211,13 +232,13 @@ void	appear_all_pet( bool_t flg_clr_map )
 		if( party_pet[i] == NULL )
 			continue;
 
-		appear_pet( party_pet[i], flg_clr_map );
+		appear_pet( party_pet[i] );
 	}
 }
 
 /**/
 
-void	appear_pet( pet_t *pet, bool_t flg_clr_map )
+void	appear_pet( pet_t *pet )
 {
 	long	x, y;
 
@@ -236,7 +257,7 @@ void	appear_pet( pet_t *pet, bool_t flg_clr_map )
 		y = pet->owner->y;
 	}
 
-	put_chr( pet, x, y, flg_clr_map );
+	put_chr( pet, x, y );
 	draw_pet( pet );
 }
 
@@ -494,7 +515,7 @@ bool_t	join_pet( pet_t *pet )
 			continue;
 
 		party_pet[i] = pet;
-		appear_pet( pet, TRUE );
+		appear_pet( pet );
 
 		return TRUE;
 	}
