@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.h,v 1.7 2004/06/30 13:20:45 bowkenken Exp $
-*****************************************************************/
+* $Id: pet.h,v 1.9 2004/12/08 04:56:17 bowkenken Exp $
+***************************************************************/
 
 #ifndef	PET_H
 #define	PET_H
@@ -43,6 +43,9 @@
 /* ڥå̾κʸ */
 #define	PET_NAME_MAX_LEN	MBR_NAME_MAX_LEN
 
+/* ڥåȥåפΥڥåȤΥ󥸥 */
+#define	PET_DUN_LEV	10
+
 typedef mnstr_t	pet_t;
 typedef mnstr_kind_t	pet_kind_t;
 
