@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.70 2004/07/26 10:02:47 bowkenken Exp $
-*****************************************************************/
+* $Id: request.c,v 1.78 2004/12/23 20:54:09 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 #include	"misc.h"
@@ -93,7 +93,7 @@
 
 #define	REQUEST_CONTRACT_RATE	20
 
-#define	REQUEST_RARE_GOODS_DROP_RATE	((rate_t)20)
+#define	REQUEST_RARE_GOODS_DROP_RATE	((rate_t)30)
 #define	REQUEST_TAME_MNSTR_MNSTR_AVE_N	4
 #define	REQUEST_TOUR_GUIDE_MNSTR_AVE_N	4
 #define	REQUEST_EXTERMINATE_MNSTR_AVE_N	4
@@ -121,6 +121,8 @@
 #define	REQUEST_WANTED_CRIMINAL_GOLD_RATE	((rate_t)3000)
 #define	REQUEST_WANTED_CRIMINAL_EXP_RATE	((rate_t)2000)
 
+#define	REQUEST_PENALTY_RATE	((rate_t)10)
+
 /**/
 
 static request_t	g_request[REQUEST_MAX_N];
@@ -869,7 +871,7 @@ void	chk_request_limit( void )
 			print_msg( FLG_NULL, MSG_REQUEST_LIMIT, name );
 			curs_attrset_dflt();
 
-			fx_energy_drain_all_mbr();
+			fx_energy_drain_all_mbr( TRUE );
 		}
 
 		free_request( req );
@@ -944,7 +946,7 @@ bool_t	chk_request_limit_client( request_t *req )
 		if( clip_pos( npc->x, npc->y ) ){
 			long	x, y;
 
-			mnstr = make_mnstr( MAP_DEL_X, MAP_DEL_Y,
+			mnstr = make_mnstr( MAP_DEL_X, MAP_DEL_Y, FALSE,
 					req->dun_max_lev, npc->mnstr_kind );
 			x = npc->x;
 			y = npc->y;
@@ -952,7 +954,7 @@ bool_t	chk_request_limit_client( request_t *req )
 				x = randm( MAP_MAX_X );
 				y = randm( MAP_MAX_Y );
 			}
-			put_chr( mnstr, x, y, FALSE );
+			put_chr( mnstr, x, y );
 		} else {
 			mnstr = NULL;
 		}
@@ -1851,12 +1853,13 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 	if( chr_kind != CHR_KIND_MBR )
 		return TRUE;
 
+	/* ƥ˼Ϥ */
+
 	if( req->kind == REQUEST_KIND_RARE_GOODS ){
 		for( i = 0; i < MBR_MAX_N; i++ ){
 			if( chk_mbr_have_rare_goods( pty->mbr[i],
 					req->rare_goods_kind,
 					req->mnstr_kind, TRUE ) ){
-				break;
 			}
 		}
 	}
@@ -1868,7 +1871,7 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 			MSG_WORDS_REQUEST_CLOSE_1 );
 
 	add_party_gold( req->prize );
-	exp_party( req->exp, TRUE );
+	exp_party( req->exp, FALSE, TRUE );
 
 	print_words( MSG_NPC_NAME_BAR_MASTER, MALE,
 			MSG_WORDS_REQUEST_CLOSE_2,
@@ -2056,7 +2059,7 @@ void	put_request_mnstr( void )
 
 		/* ɸΥ󥹥 */
 
-		p = make_mnstr( MAP_DEL_X, MAP_DEL_Y,
+		p = make_mnstr( MAP_DEL_X, MAP_DEL_Y, FALSE,
 				dun->lev, mnstr_kind );
 		if( p == NULL )
 			continue;
@@ -2080,12 +2083,11 @@ void	put_request_mnstr( void )
 
 			mbr = get_mbr_randm( MAP_DEL_X, MAP_DEL_Y );
 			if( mbr != NULL ){
-				put_chr( p, mbr->x, mbr->y, FALSE );
+				put_chr( p, mbr->x, mbr->y );
 				return;
 			}
 		}
-		put_chr( p, randm( MAP_MAX_X ),
-				randm( MAP_MAX_Y ), FALSE );
+		put_chr( p, randm( MAP_MAX_X ), randm( MAP_MAX_Y ) );
 	}
 }
 
@@ -2093,8 +2095,6 @@ void	put_request_mnstr( void )
 
 char	*cb_menu_request_mbr( menu_t **pp, menu_t **dflt )
 {
-	chk_finish_request_rare_goods();
-
 	return( set_menu_request( pp, dflt,
 			cb_menu_sel_request_mbr, TRUE ) );
 }
@@ -2189,7 +2189,7 @@ char	*set_menu_request(
 	*dflt = NULL;
 
 	if( n <= 0 ){
-		print_msg( FLG_NULL, MSG_ERR_MENU_REQUEST );
+		print_msg( FLG_MSG_ERR, MSG_ERR_MENU_REQUEST );
 		return STR_MENU_CANCEL;
 	}
 
@@ -2270,17 +2270,27 @@ bool_t	ask_contract_request( request_t *req )
 
 bool_t	ask_cancel_request( request_t *req )
 {
+	char	msg[MENU_MSG_MAX_LEN + 1];
+	gold_t	penalty;
 	ask_t	ask;
 
 	if( req == NULL )
 		return FALSE;
 
-	ask = exec_menu_ask( MSG_TTL_MENU_REQUEST_MBR_CANCEL,
-			ASK_NO, TRUE );
+	penalty = req->prize * REQUEST_PENALTY_RATE / _100_PERCENT;
 
+	sprintf( msg, MSG_TTL_MENU_REQUEST_MBR_CANCEL, penalty );
+	ask = exec_menu_ask( msg, ASK_NO, TRUE );
 	if( ask != ASK_YES )
 		return FALSE;
 
+	if( get_party_gold() < penalty ){
+		print_msg( FLG_MSG_ERR, MSG_ERR_MENU_REQUEST_MBR_CANCEL,
+				penalty - get_party_gold() );
+		return FALSE;
+	}
+	sub_party_gold( penalty );
+
 	print_words( MSG_NPC_NAME_BAR_MASTER, MALE,
 			MSG_WORDS_REQUEST_CANCEL,
 			MSG_WORDS_REQUEST_CANCEL );
