@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,17 +25,27 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: resi.h,v 1.14 2004/06/30 13:20:45 bowkenken Exp $
-*****************************************************************/
+* $Id: resi.h,v 1.17 2004/12/13 14:14:23 bowkenken Exp $
+***************************************************************/
 
 #ifndef	RESI_H
 #define	RESI_H
 
 /*  */
 
-#define	RESI_PERFECT_N	30000	/*  */
+#define	RESI_300	300
+#define	RESI_200	200
+#define	RESI_150	150
+#define	RESI_120	120
+#define	RESI_100	100
+#define	RESI__80	80
+#define	RESI__50	50
+#define	RESI__30	30
+#define	RESI_PRF	30000	/*  */
+#define	RESI_PERFECT_N	(RESI_PRF)	/*  */
 #define	RESI_MAX_N	(RESI_PERFECT_N - 1)	/*  */
 
+/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	RESI_KIND_KNOC,	/*  */
 	RESI_KIND_SLAS,	/* · */
