@@ -7,6 +7,7 @@ extern "C" {
 void	init_spell( void );
 void	init_spell_debug( void );
 void	init_spell_dflt( void );
+void	init_spell_nin( void );
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt );
 char	*cb_menu_dflt_spell_mag( menu_t **pp, menu_t **dflt );
 char	*cb_menu_dflt_spell_sor( menu_t **pp, menu_t **dflt );
@@ -79,6 +80,10 @@ bool_t	set_chr_learned_spell( chr_t *chr, spell_kind_t kind, bool_t flg );
 void	learn_spell_pri( chr_t *chr );
 void	learn_spell_sha( chr_t *chr );
 void	learn_spell_bar( chr_t *chr );
+bool_t	chk_chr_learned_spell_nin(
+	chr_t *chr, spell_kind_t kind,
+	bool_t flg_test
+);
 bool_t	chk_learn_spell_item( chr_t *chr, spell_kind_t kind );
 char	*get_spell_vfx_str( spell_kind_t spell_kind );
 cast_tab_t	*get_cast_tab( chr_t *chr, spell_kind_t kind );
