@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.118 2004/07/31 07:27:27 bowkenken Exp $
-*****************************************************************/
+* $Id: spell.c,v 1.124 2004/12/23 20:54:09 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -176,9 +176,11 @@ void	init_spell_debug( void )
 	long	m;
 	spell_kind_t	k;
 
+#if	0
 	m = 0;
 	for( k = SPELL_KIND_NIN_MIN_N + 1; k < SPELL_KIND_NIN_MAX_N; k++ )
 		cast_tab[m][k].flg_cast = TRUE;
+#endif
 
 	m = 3;
 	for( k = SPELL_KIND_PRI_MIN_N + 1; k < SPELL_KIND_PRI_MAX_N; k++ ){
@@ -234,6 +236,19 @@ void	init_spell_dflt( void )
 
 /**/
 
+void	init_spell_nin( void )
+{
+	chr_t	*chr;
+	spell_kind_t	k;
+
+	chr = get_mbr_randm( MAP_DEL_X, MAP_DEL_Y );
+
+	for( k = SPELL_KIND_NIN_MIN_N + 1; k < SPELL_KIND_NIN_MAX_N; k++ )
+		chk_chr_learned_spell_nin( chr, k, TRUE );
+}
+
+/**/
+
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 {
 	pos_t	*crsr;
@@ -1435,13 +1450,19 @@ void	chr_cast_spell_sub(
 	}
 
 	/* ʸ뤫å */
-	if( flg_chr )
-		if( !chk_spell( chr, (chr_t *)p, tab, flg_item ) )
-			return;
+	if( flg_chr && !chk_spell( chr, (chr_t *)p, tab, flg_item ) ){
+		curs_attrset_chr( chr, -1, FALSE );
+		print_msg( FLG_NULL, MSG_FAIL_SPELL,
+				chr->name, tab->name );
+		curs_attrset_dflt();
+		return;
+	}
 
 	if( flg_chr && chk_flg( ((chr_t *)p)->stat, FLG_STAT_IRON_BODY ) ){
+		curs_attrset_chr( (chr_t *)p, +1, FALSE );
 		print_msg( FLG_NULL, MSG_REPEL_SPELL,
 				((chr_t *)p)->name, chr->name );
+		curs_attrset_dflt();
 		return;
 	}
 
@@ -1672,7 +1693,7 @@ void	chr_cast_spell_sub(
 				FX_AVE_TURN_POW_DOWN_ABL );
 		break;
 	case SPELL_KIND_ENERGY_DRAIN:
-		fx_energy_drain( p );
+		fx_energy_drain( p, FALSE );
 		break;
 	case SPELL_KIND_SLOW:
 		fx_speed_up( chr, (chr_t *)p, -1, FX_AVE_TURN_SPEED_DOWN );
@@ -2001,6 +2022,15 @@ bool_t	chk_spell(
 	else
 		o_abl = tab->abl;
 
+	if( o_abl != ABL_KIND_MAX_N ){
+		rate_t	rate;
+
+		rate = calc_rate_equip( o_p, o_abl, get_sub_abl( o_abl ) );
+		if( !rate_randm( rate ) ){
+			return FALSE;
+		}
+	}
+
 	return( !resi_roll( o_p, o_abl, d_p, tab->resi ) );
 }
 
@@ -2311,7 +2341,12 @@ bool_t	chk_can_chr_cast( chr_t *chr, spell_kind_t kind )
 	if( get_lev( chr, spell_tab->abl ) < spell_tab->lev )
 		return FALSE;
 
-	return chk_chr_learned_spell( chr, kind );
+	if( chk_chr_learned_spell( chr, kind ) )
+		return TRUE;
+	if( chk_chr_learned_spell_nin( chr, kind, FALSE ) )
+		return TRUE;
+
+	return FALSE;
 }
 
 /**/
@@ -2473,6 +2508,115 @@ void	learn_spell_bar( chr_t *chr )
 
 /**/
 
+bool_t	chk_chr_learned_spell_nin(
+	chr_t *chr, spell_kind_t kind,
+	bool_t flg_test
+)
+{
+	item_t	*eq;
+	scroll_tab_t	*tab;
+	bool_t	flg_learn;
+
+	if( chr == NULL )
+		return FALSE;
+
+	if( chr->kind != CHR_KIND_MBR )
+		return TRUE;	/* FALSE ǤϤʤ */
+
+	if( kind <= SPELL_KIND_NIN_MIN_N )
+		return FALSE;
+	if( kind >= SPELL_KIND_NIN_MAX_N )
+		return FALSE;
+
+	flg_learn = FALSE;
+
+	switch( kind ){
+	default:
+		if( flg_test ){
+			print_err( MSG_ERR_SPELL_NIN_LEARNED,
+					get_spell_name( kind ) );
+			exit_game( EXIT_FAILURE );
+		} else {
+			print_msg( FLG_MSG_ERR, MSG_ERR_SPELL_NIN_LEARNED,
+					get_spell_name( kind ) );
+		}
+		return FALSE;
+	case SPELL_KIND_NIN_MIN_N:
+	case SPELL_KIND_TYPHOON:
+	case SPELL_KIND_CONFLAGRATION:
+	case SPELL_KIND_EARTHQUAKE:
+	case SPELL_KIND_THUNDERCLOUD:
+	case SPELL_KIND_INUNDATION:
+	case SPELL_KIND_SUBSTITUTE:
+	case SPELL_KIND_BURNING_HANDS:
+	case SPELL_KIND_DUMMY_NIN_1:
+	case SPELL_KIND_DUMMY_NIN_2:
+	case SPELL_KIND_MIND_READING:
+	case SPELL_KIND_NIN_MAX_N:
+		break;
+	}
+
+	eq = get_mbr_item_asgn_equip( chr );
+	eq = &(eq[EQUIP_KIND_HEAD]);
+	if( eq->kind != ITEM_KIND_SCROLL )
+		return FALSE;
+
+	tab = eq->tab.scroll;
+	if( tab == NULL )
+		return FALSE;
+
+	switch( kind ){
+	default:
+		break;
+	case SPELL_KIND_NIN_MIN_N:
+		break;
+	case SPELL_KIND_TYPHOON:
+		if( tab->kind == SCROLL_KIND_TYPHOON )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_CONFLAGRATION:
+		if( tab->kind == SCROLL_KIND_CONFLAGRATION )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_EARTHQUAKE:
+		if( tab->kind == SCROLL_KIND_EARTHQUAKE )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_THUNDERCLOUD:
+		if( tab->kind == SCROLL_KIND_THUNDERCLOUD )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_INUNDATION:
+		if( tab->kind == SCROLL_KIND_INUNDATION )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_SUBSTITUTE:
+		if( tab->kind == SCROLL_KIND_SUBSTITUTE )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_BURNING_HANDS:
+		if( tab->kind == SCROLL_KIND_BURNING_HANDS )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_DUMMY_NIN_1:
+	case SPELL_KIND_DUMMY_NIN_2:
+		break;
+	case SPELL_KIND_MIND_READING:
+		if( tab->kind == SCROLL_KIND_MIND_READING )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_NIN_MAX_N:
+		break;
+	}
+
+	if( flg_learn && !flg_test )
+		set_chr_learned_spell( chr, kind, TRUE );
+
+	return flg_learn;
+}
+
+/**/
+
 bool_t	chk_learn_spell_item( chr_t *chr, spell_kind_t kind )
 {
 	item_t	*item;
@@ -2811,9 +2955,7 @@ cast_tab_t	*get_cast_tab( chr_t *chr, spell_kind_t kind )
 		return NULL;
 
 	m = chr->ls_mbr_n;
-	for( k = SPELL_KIND_NULL + 1; k < SPELL_KIND_MAX_N; k++ ){
-		if( cast_tab[m][k].kind == SPELL_KIND_NULL )
-			break;
+	for( k = SPELL_KIND_NULL; k < SPELL_KIND_MAX_N; k++ ){
 		if( cast_tab[m][k].kind == SPELL_KIND_MAX_N )
 			break;
 
