@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.h,v 1.28 2004/07/26 10:02:47 bowkenken Exp $
-*****************************************************************/
+* $Id: spell.h,v 1.31 2004/12/18 17:38:29 bowkenken Exp $
+***************************************************************/
 
 #ifndef	SPELL_H
 #define	SPELL_H
@@ -89,4 +89,74 @@ typedef struct {
 	vfx_kind_t	vfx_kind;	/* и */
 } spell_tab_t;
 
+/*  HP */
+
+#define	SPELL_HP_S	32
+#define	SPELL_HP_A	16
+#define	SPELL_HP_B	8
+#define	SPELL_HP_C	4
+#define	SPELL_HP_D	2
+
+#define	SPELL_HP_1	1
+#define	SPELL_HP_0	0
+
+/*  MP */
+
+#define	SPELL_MP_SSS	40
+#define	SPELL_MP_SS	30
+#define	SPELL_MP_S	20
+#define	SPELL_MP_AAA	12
+#define	SPELL_MP_AA	11
+#define	SPELL_MP_A	10
+#define	SPELL_MP_BBB	9
+#define	SPELL_MP_BB	8
+#define	SPELL_MP_B	7
+#define	SPELL_MP_CCC	6
+#define	SPELL_MP_CC	5
+#define	SPELL_MP_C	4
+#define	SPELL_MP_DDD	3
+#define	SPELL_MP_DD	2
+#define	SPELL_MP_D	1
+
+#define	SPELL_MP_SUM_SSS	400
+#define	SPELL_MP_SUM_SS	300
+#define	SPELL_MP_SUM_S	200
+#define	SPELL_MP_SUM_AAA	120
+#define	SPELL_MP_SUM_AA	110
+#define	SPELL_MP_SUM_A	100
+#define	SPELL_MP_SUM_BBB	90
+#define	SPELL_MP_SUM_BB	80
+#define	SPELL_MP_SUM_B	70
+#define	SPELL_MP_SUM_CCC	60
+#define	SPELL_MP_SUM_CC	50
+#define	SPELL_MP_SUM_C	40
+#define	SPELL_MP_SUM_DDD	30
+#define	SPELL_MP_SUM_DD	20
+#define	SPELL_MP_SUM_D	10
+
+#define	SPELL_MP_1	1
+#define	SPELL_MP_0	0
+
+/*  GOLD */
+
+#define	SPELL_GOLD_S	((gold_t)10000)
+#define	SPELL_GOLD_A	((gold_t)1000)
+#define	SPELL_GOLD_B	((gold_t)100)
+#define	SPELL_GOLD_C	((gold_t)10)
+#define	SPELL_GOLD_D	((gold_t)1)
+
+#define	SPELL_GOLD_1	((gold_t)1)
+#define	SPELL_GOLD_0	((gold_t)0)
+
+/*  */
+
+#define	SPELL_RESI_S	((rate_t)20)
+#define	SPELL_RESI_A	((rate_t)15)
+#define	SPELL_RESI_B	((rate_t)10)
+#define	SPELL_RESI_C	((rate_t)5)
+#define	SPELL_RESI_D	((rate_t)1)
+
+#define	SPELL_RESI_1	((rate_t)1)
+#define	SPELL_RESI_0	((rate_t)0)
+
 #endif	/* SPELL_H */
