@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.2 2004/07/30 11:19:23 bowkenken Exp $
-*****************************************************************/
+* $Id: tmenu-tab.h,v 1.5 2004/12/07 12:44:22 bowkenken Exp $
+***************************************************************/
 
 #ifndef	TMENU_TAB_H
 #define	TMENU_TAB_H
@@ -1322,6 +1322,26 @@ menu_t	ls_menu_magic_guild[] = {
 /* []  */
 /* [Ǧ] */
 /*  */
+	{
+		"/Magic Guild/Collect gold",
+		"<Item>",
+		'L',
+		"",
+		N_MSG_MENU_SHOP_COLLECT_GOLD, "",
+		cb_menu_shop_collect_gold, NULL,
+		FLG_NULL,
+	},
+
+	{
+		"/Magic Guild/Divide gold",
+		"<Item>",
+		'V',
+		"",
+		N_MSG_MENU_SHOP_DIVIDE_GOLD, "",
+		cb_menu_shop_divide_gold, NULL,
+		FLG_NULL,
+	},
+
 	{
 		"",
 		"",
@@ -1676,10 +1696,19 @@ menu_t	ls_menu_inn[] = {
 	{
 		"/Inn/Stay",
 		"<Item>",
-		'C',
+		'S',
 		"",
 		N_MSG_MENU_INN_STAY, "",
-		cb_menu_inn_stay, NULL,
+		cb_menu_inn_stay, (void *)FALSE,
+		FLG_NULL,
+	},
+	{
+		"/Inn/Short Stay",
+		"<Item>",
+		'R',
+		"",
+		N_MSG_MENU_INN_SHORT_STAY, "",
+		cb_menu_inn_short_stay, (void *)TRUE,
 		FLG_NULL,
 	},
 	{
