@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.65 2004/07/26 10:02:47 bowkenken Exp $
-*****************************************************************/
+* $Id: tmenu.c,v 1.75 2004/12/25 06:33:08 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -90,8 +90,6 @@
 
 #define	ORDER_MILK_LEV	20
 
-#define	PET_DUN_LEV	10
-
 /**/
 
 #include	"tmenu-tab.h"
@@ -272,7 +270,7 @@ char	*cb_menu_temple_remove_curse( menu_t **pp, menu_t **dflt )
 				MSG_MENU_REMOVE_CURSE,
 				g_sel_mbr->name );
 	} else {
-		print_msg( FLG_NULL,
+		print_msg( FLG_MSG_ERR,
 				MSG_MENU_REMOVE_CURSE_ERR,
 				g_sel_mbr->name );
 	}
@@ -317,7 +315,7 @@ char	*cb_menu_temple_cure_status( menu_t **pp, menu_t **dflt )
 				MSG_MENU_CURE_STATUS,
 				g_sel_mbr->name );
 	} else {
-		print_msg( FLG_NULL,
+		print_msg( FLG_MSG_ERR,
 				MSG_MENU_CURE_STATUS_ERR,
 				g_sel_mbr->name );
 	}
@@ -338,13 +336,6 @@ char	*cb_menu_temple_resurrection( menu_t **pp, menu_t **dflt )
 	if( chk_flg( g_sel_mbr->stat, FLG_STAT_NOT_EXIST ) )
 		return STR_MENU_ERR;
 
-	if( !chk_flg( g_sel_mbr->stat, FLG_STAT_DEAD ) ){
-		print_msg( FLG_NULL,
-				MSG_MENU_RESURRECTION_ERR,
-				g_sel_mbr->name );
-		return STR_MENU_CANCEL;
-	}
-
 	price = get_price_temple_resurrection( g_sel_mbr );
 	if( is_pet( g_sel_mbr ) )
 		chr_pay = g_sel_mbr->owner;
@@ -367,6 +358,13 @@ char	*cb_menu_temple_resurrection( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
+	if( !chk_flg( g_sel_mbr->stat, FLG_STAT_DEAD ) ){
+		print_msg( FLG_MSG_ERR,
+				MSG_MENU_RESURRECTION_ERR,
+				g_sel_mbr->name );
+		return STR_MENU_CANCEL;
+	}
+
 	fx_resurrection( g_sel_mbr, FALSE );
 
 	/* ֤ʤƤʧ */
@@ -551,7 +549,7 @@ char	*menu_order_sel_mbr( void )
 	p[k].path[0] = '\0';
 
 	if( mbr_n <= 0 ){
-		print_msg( FLG_NULL, MSG_ERR_MENU_NOT_EXIST_MBR );
+		print_msg( FLG_MSG_ERR, MSG_ERR_MENU_NOT_EXIST_MBR );
 		return STR_MENU_ERR;
 	}
 
@@ -1010,7 +1008,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 	if( price <= 0 ){
 		if( (g_deal_kind == DEAL_KIND_SALE_ITEM)
 				|| (g_deal_kind == DEAL_KIND_SALE_EQUIP) ){
-			print_msg( FLG_NULL, MSG_NO_DEAL, art->art_name );
+			print_msg( FLG_MSG_ERR, MSG_NO_DEAL, art->art_name );
 			return STR_MENU_CANCEL;
 		}
 	}
@@ -1090,8 +1088,6 @@ bool_t	menu_shop_buy(
 		return FALSE;
 	}
 
-	add_chr_gold( g_sel_mbr, -price );
-
 	tmp = alloc_item();
 	if( tmp == NULL )
 		return FALSE;
@@ -1105,7 +1101,7 @@ bool_t	menu_shop_buy(
 	if( item->stock <= 0 )
 		inc_item( item, -item->n );
 
-	print_msg( FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT,
+	print_msg( FLG_MSG_NO_MORE,
 			MSG_MENU_REACHED_BUY, item->name );
 
 	return TRUE;
@@ -1185,26 +1181,36 @@ bool_t	menu_shop_sale(
 		break;
 	}
 
-	tmp = alloc_item();
-	if( tmp == NULL )
-		return FALSE;
-	copy_item( tmp, item );
-	tmp->stock = 1;
-
-	if( chk_package_item( item ) ){
-		ins_ls_item( asgn, tmp );
-		inc_item( item, -item->n );
-	} else {
-		tmp->n = 1;
-		inc_item( tmp, -(tmp->n - 1) );
-
-		ins_ls_item( asgn, tmp );
-		inc_item( item, -1 );
-	}
-
 	print_msg( FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT,
 			MSG_MENU_REACHED_SALE, item->name );
 
+	if( (asgn == NULL) || chk_flg( item->flg, FLG_ITEM_CURSED ) ){
+		if( chk_package_item( item ) ){
+			del_item( item );
+		} else {
+			inc_item( item, -1 );
+		}
+	} else {
+		tmp = alloc_item();
+		if( tmp == NULL )
+			return FALSE;
+		copy_item( tmp, item );
+		tmp->stock = 1;
+
+		if( chk_package_item( item ) ){
+			ins_ls_item( asgn, tmp );
+			inc_item( item, -item->n );
+		} else {
+			tmp->n = 1;
+			inc_item( tmp, -(tmp->n - 1) );
+
+			ins_ls_item( asgn, tmp );
+			inc_item( item, -1 );
+		}
+
+		identify_item( tmp );
+	}
+
 	return TRUE;
 }
 
@@ -2213,7 +2219,7 @@ char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt )
 		if( p[n].name[0] == '\0' )
 			break;
 	if( n >= CLASS_MAX_N ){
-		print_msg( FLG_NULL, MSG_S, MSG_ERR_MENU_NEW_CLASS );
+		print_msg( FLG_MSG_ERR, MSG_S, MSG_ERR_MENU_NEW_CLASS );
 		return STR_MENU_ERR;
 	}
 
@@ -2274,7 +2280,7 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 		draw_edit_class( org, work, n, TRUE, flg_sel_add );
 		prev_n = n;
 
-		switch( get_key( FALSE ) ){
+		switch( get_key( TRUE ) ){
 		case CASE_CANCEL:
 			if( exec_menu_ask_edit_class( org, work, flg_new ) )
 				return 0;
@@ -2402,7 +2408,7 @@ bool_t	exec_menu_ask_edit_class(
 
 	if( ask == ASK_YES ){
 		if( total != _100_PERCENT ){
-			print_msg( FLG_MSG_MORE, MSG_S,
+			print_msg( FLG_MSG_ERR | FLG_MSG_MORE, MSG_S,
 					MSG_ERR_MENU_EDIT_CLASS );
 			return FALSE;	/* Cancel */
 		} else {
@@ -2543,10 +2549,23 @@ char	*menu_inn( void )
 {
 	menu_t	*p;
 
+	/*  */
+
 	p = srch_menu( ls_menu_inn, "Stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_INN_STAY, (long)get_price_inn() );
+	sprintf( p->msg, MSG_MENU_INN_STAY,
+			(long)get_price_inn( FALSE ) );
+
+	/* ٷ */
+
+	p = srch_menu( ls_menu_inn, "Short Stay" );
+	if( p == NULL )
+		return STR_MENU_ERR;
+	sprintf( p->msg, MSG_MENU_INN_SHORT_STAY,
+			(long)get_price_inn( TRUE ) );
+
+	/**/
 
 	return exec_menu( ls_menu_inn, NULL, NULL );
 }
@@ -2556,27 +2575,39 @@ char	*menu_inn( void )
 char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 {
 	party_t	*pty = get_party();
-	long	mbr_n;
+	bool_t	flg_short;
+	gold_t	price;
 	bool_t	flg_pay;
+	long	mbr_n;
+
+	flg_short = (bool_t)(long)((*pp)->arg);
+	price = get_price_inn( flg_short );
 
 	flg_pay = TRUE;
 	for( mbr_n = 0; mbr_n < MBR_MAX_N; mbr_n++ )
-		if( !chk_pay( pty->mbr[mbr_n], get_price_inn() ) )
+		if( !chk_pay( pty->mbr[mbr_n], price ) )
 			flg_pay = FALSE;
 
 	if( !flg_pay )
 		return STR_MENU_CANCEL;
 
 	for( mbr_n = 0; mbr_n < MBR_MAX_N; mbr_n++ )
-		add_chr_gold( pty->mbr[mbr_n], -get_price_inn() );
+		add_chr_gold( pty->mbr[mbr_n], -price );
 
-	stay_inn();
+	stay_inn( flg_short );
 
 	return NULL;
 }
 
 /**/
 
+char	*cb_menu_inn_short_stay( menu_t **pp, menu_t **dflt )
+{
+	return cb_menu_inn_stay( pp, dflt );
+}
+
+/**/
+
 char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls, *p;
@@ -2672,7 +2703,7 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 	}
 
 	if( !flg ){
-		print_msg( FLG_NULL, MSG_ERR_SPELL, g_sel_mbr->name );
+		print_msg( FLG_MSG_ERR, MSG_ERR_SPELL, g_sel_mbr->name );
 		return STR_MENU_CANCEL;
 	}
 
@@ -2829,7 +2860,8 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 	ls[k].path[0] = '\0';
 
 	if( n <= 0 ){
-		print_msg( FLG_NULL, MSG_S, MSG_ERR_MENU_PET_SHOP_TAKE );
+		print_msg( FLG_MSG_ERR, MSG_S,
+				MSG_ERR_MENU_PET_SHOP_TAKE );
 		return STR_MENU_CANCEL;
 	}
 
@@ -2941,7 +2973,8 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 	ls[k].path[0] = '\0';
 
 	if( n <= 0 ){
-		print_msg( FLG_NULL, MSG_S, MSG_ERR_MENU_PET_SHOP_LEAVE );
+		print_msg( FLG_MSG_ERR, MSG_S,
+				MSG_ERR_MENU_PET_SHOP_LEAVE );
 		return STR_MENU_CANCEL;
 	}
 
@@ -3057,7 +3090,8 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	ls[k].path[0] = '\0';
 
 	if( n <= 0 ){
-		print_msg( FLG_NULL, MSG_S, MSG_ERR_MENU_PET_SHOP_NAME );
+		print_msg( FLG_MSG_ERR, MSG_S,
+				MSG_ERR_MENU_PET_SHOP_NAME );
 		return STR_MENU_CANCEL;
 	}
 
@@ -3170,7 +3204,8 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 	ls[k].path[0] = '\0';
 
 	if( n <= 0 ){
-		print_msg( FLG_NULL, MSG_S, MSG_ERR_MENU_PET_SHOP_REMOVE );
+		print_msg( FLG_MSG_ERR, MSG_S,
+				MSG_ERR_MENU_PET_SHOP_REMOVE );
 		return STR_MENU_CANCEL;
 	}
 
@@ -3191,7 +3226,9 @@ char	*cb_menu_pet_shop_remove_sel( menu_t **pp, menu_t **dflt )
 	if( pet == NULL )
 		return STR_MENU_ERR;
 
+	curs_attrset_chr( pet, -1, TRUE );
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_ASK_REMOVE, pet->name );
+	curs_attrset_dflt();
 
 	ask = exec_menu_ask( MSG_TTL_MENU_PET_SHOP_ASK_REMOVE,
 			ASK_NO, TRUE );
@@ -3204,7 +3241,10 @@ char	*cb_menu_pet_shop_remove_sel( menu_t **pp, menu_t **dflt )
 		return STR_MENU_CANCEL;
 	}
 
+	curs_attrset_chr( pet, -1, TRUE );
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_REMOVE_SUCCESS, pet->name );
+	curs_attrset_dflt();
+
 	remove_pet( pet );
 
 	return "/Pet Shop";
