@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town-tab.h,v 1.1 2004/07/26 10:02:47 bowkenken Exp $
-*****************************************************************/
+* $Id: town-tab.h,v 1.4 2004/12/06 06:18:18 bowkenken Exp $
+***************************************************************/
 
 #ifndef	TOWN_TAB_H
 #define	TOWN_TAB_H
@@ -193,12 +193,12 @@ art_ls_wpn_t	art_ls_wpn[] = {
 	{ ITEM_KIND_WPN, 4, WPN_KIND_LIGHT_CROSS_BOW },
 	{ ITEM_KIND_WPN, 4, WPN_KIND_HEAVY_CROSS_BOW },
 	{ ITEM_KIND_WPN, 4, WPN_KIND_BLOW_GUN },
-	{ ITEM_KIND_WPN, 10, WPN_KIND_BULLET },
-	{ ITEM_KIND_WPN, 10, WPN_KIND_ARW },
-	{ ITEM_KIND_WPN, 10, WPN_KIND_BOLT },
-	{ ITEM_KIND_WPN, 10, WPN_KIND_NEEDLE },
-	{ ITEM_KIND_WPN, 10, WPN_KIND_DAGGER },
-	{ ITEM_KIND_WPN, 10, WPN_KIND_DARTS },
+	{ ITEM_KIND_WPN, 100, WPN_KIND_BULLET },
+	{ ITEM_KIND_WPN, 100, WPN_KIND_ARW },
+	{ ITEM_KIND_WPN, 100, WPN_KIND_BOLT },
+	{ ITEM_KIND_WPN, 100, WPN_KIND_NEEDLE },
+	{ ITEM_KIND_WPN, 100, WPN_KIND_DAGGER },
+	{ ITEM_KIND_WPN, 100, WPN_KIND_DARTS },
 	{ ITEM_KIND_NULL, 0, WPN_KIND_NULL },
 };
 
@@ -449,6 +449,16 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 	},
 /* scroll */
 	{ ITEM_KIND_SCROLL, 12,
+		POTION_KIND_NULL,
+		SCROLL_KIND_RECALL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_SCROLL, 100,
 		POTION_KIND_NULL,
 		SCROLL_KIND_IDENTIFY_ITEM,
 		STICK_KIND_NULL,
