@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.92 2004/07/26 10:29:52 bowkenken Exp $
-*****************************************************************/
+* $Id: town.c,v 1.102 2004/12/08 04:56:17 bowkenken Exp $
+***************************************************************/
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
@@ -128,7 +128,10 @@
 
 /**/
 
-#define	CHARGE_STAY_INN	((gold_t)50)
+#define	PRICE_NOT_IDENTIFIED_RATE	((rate_t)100)
+
+#define	CHARGE_STAY_INN_STAY	((gold_t)50)
+#define	CHARGE_STAY_INN_SHORT_STAY	((gold_t)50)
 
 #define	PRICE_WPN_MIN	50
 #define	PRICE_WPN_RATE	((rate_t)10)
@@ -244,9 +247,7 @@ static bool_t	g_flg_night;
 
 void	init_town( void )
 {
-	g_morning_glow_n = 4;
-	g_evening_glow_n = 4;
-	g_flg_night = chk_night();
+	reset_glow();
 
 	init_town_ptn_col_tab();
 
@@ -259,6 +260,18 @@ void	init_town( void )
 
 /**/
 
+void	reset_glow( void )
+{
+	g_morning_glow_n = 4;
+	g_evening_glow_n = 4;
+	g_flg_night = chk_night();
+
+	chk_morning_glow( get_turn() );
+	chk_evening_glow( get_turn() );
+}
+
+/**/
+
 void	init_town_ptn_col_tab( void )
 {
 	long	i, max_i;
@@ -512,7 +525,7 @@ void	make_town( void )
 	long	n;
 	long	i;
 
-	reset_dun();
+	reset_dun( TRUE );
 
 	make_town_ptn();
 
@@ -1191,7 +1204,7 @@ bool_t	chk_shop_face_ls( void )
 
 /**/
 
-bool_t	appear_party_town( bool_t flg_clr_map )
+bool_t	appear_party_town( void )
 {
 	dun_t *dun;
 	long	i, j;
@@ -1227,10 +1240,8 @@ bool_t	appear_party_town( bool_t flg_clr_map )
 	if( !flg_find )
 		return FALSE;
 
-	if( flg_clr_map ){
-		clr_map_all_mbr();
-		clr_map_all_pet();
-	}
+	clr_map_all_mbr();
+	clr_map_all_pet();
 
 	for( n = 0; n < MBR_MAX_N; n++ ){
 		long	nx, ny;
@@ -1241,10 +1252,10 @@ bool_t	appear_party_town( bool_t flg_clr_map )
 
 		nx = pty->square.x + pty->square.chr_pos[n].x;
 		ny = pty->square.y + pty->square.chr_pos[n].y;
-		put_chr( pty->mbr[n], nx, ny, FALSE );
+		put_chr( pty->mbr[n], nx, ny );
 	}
 
-	appear_all_pet( flg_clr_map );
+	appear_all_pet();
 
 	return TRUE;
 }
@@ -1284,7 +1295,6 @@ bool_t	enter_shop( void )
 	char	face_mnr;
 	long	dr_n;
 	shop_n_t	shop_n;
-	long	i;
 
 	dun = get_dun();
 	pty = get_party();
@@ -1305,18 +1315,6 @@ bool_t	enter_shop( void )
 	clr_map_all_mbr();
 	clr_map_all_pet();
 
-	for( i = 0; i < MBR_MAX_N; i++ ){
-		pty->mbr[i]->x = MAP_DEL_X;
-		pty->mbr[i]->y = MAP_DEL_Y;
-	}
-	for( i = 0; i < PET_MAX_N; i++ ){
-		if( pet[i] == NULL )
-			continue;
-
-		pet[i]->x = MAP_DEL_X;
-		pet[i]->y = MAP_DEL_Y;
-	}
-
 	while( 1 ){
 		switch( face_mnr ){
 		case FACE_MNR_SHOP_INN:
@@ -1347,7 +1345,7 @@ bool_t	enter_shop( void )
 		}
 
 		if( chk_not_exist_all_mbr() ){
-			print_msg( FLG_NULL, MSG_S,
+			print_msg( FLG_MSG_ERR, MSG_S,
 					MSG_ERR_NOT_EXIST_ALL_MBR );
 		} else {
 			party_exit_shop( dr_n );
@@ -1418,8 +1416,8 @@ void	party_exit_shop( long dr_n )
 	if( flg_force ){
 		/* ̵˽Ф */
 
-		if( !appear_party_town( FALSE ) )
-			appear_party( FALSE );
+		if( !appear_party_town() )
+			appear_party();
 	} else {
 		/* ̤˽Ф */
 
@@ -1433,10 +1431,10 @@ void	party_exit_shop( long dr_n )
 
 			x = pty->square.x + pty->square.chr_pos[j].x;
 			y = pty->square.y + pty->square.chr_pos[j].y;
-			put_chr( pty->mbr[j], x, y, FALSE );
+			put_chr( pty->mbr[j], x, y );
 		}
 
-		appear_all_pet( TRUE );
+		appear_all_pet();
 	}
 
 	set_flg_find_all_mnstr();
@@ -1520,7 +1518,7 @@ bool_t	chk_shop_open( shop_n_t shop_n, bool_t flg_print )
 		ret = FALSE;
 
 	if( !ret && flg_print ){
-		print_msg( FLG_NULL, MSG_ERR_SHOP_CLOSE,
+		print_msg( FLG_MSG_ERR, MSG_ERR_SHOP_CLOSE,
 				get_shop_name( shop_n ),
 				open_turn / TURN_PER_HOUR,
 				close_turn / TURN_PER_HOUR );
@@ -1572,21 +1570,25 @@ bool_t	chk_package_item( item_t *item )
 
 /**/
 
-void	stay_inn( void )
+void	stay_inn( bool_t flg_short_stay )
 {
 	party_t	*pty = get_party();
 	pet_t	**pet = get_party_pet();
 	long	turn;
+	fx_t	*fx;
 	long	i, j;
 
-	turn = TURN_A_DAY - (get_turn() % TURN_A_DAY);
-	turn += 7 * TURN_PER_HOUR;
+	if( flg_short_stay ){
+		turn = 12 * TURN_PER_HOUR;
+	} else {
+		turn = TURN_A_DAY - (get_turn() % TURN_A_DAY);
+		turn += 7 * TURN_PER_HOUR;
+	}
 
 	dec_turn_fx_all_mbr( turn );
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		mbr_t	*mbr;
-		fx_t	*fx;
 
 		mbr = pty->mbr[i];
 
@@ -1595,16 +1597,22 @@ void	stay_inn( void )
 			continue;
 		}
 
-		/* ǤˤƤϲʤ */
+		/* ǤˤƤʤ HP  */
 		fx = srch_fx( &(mbr->fx), FX_KIND_POISON );
 		if( fx == NULL ){
 			mbr->abl.hp.n = mbr->abl.hp.max;
 		}
+
+		/* MP  */
 		mbr->abl.mp.n = mbr->abl.mp.max;
 
-		for( j = 0; j < RESI_KIND_MAX_N; j++ )
+		/* ͤꥻå */
+		for( j = 0; j < RESI_KIND_MAX_N; j++ ){
+			reset_mbr_resi( mbr );
 			mbr->resi[j].n = mbr->resi[j].max;
+		}
 
+		/* 줤 */
 		mbr->fx_data.drunk_rate = (rate_t)0;
 
 		/* Τ򤪤ܤ */
@@ -1625,13 +1633,39 @@ void	stay_inn( void )
 			continue;
 		}
 
-		pet[i]->abl.hp.n = pet[i]->abl.hp.max;
+		/* ǤˤƤʤ HP  */
+		fx = srch_fx( &(pet[i]->fx), FX_KIND_POISON );
+		if( fx == NULL ){
+			pet[i]->abl.hp.n = pet[i]->abl.hp.max;
+		}
+
+		/* MP  */
+		pet[i]->abl.mp.n = pet[i]->abl.mp.max;
+
+		/* ͤꥻå */
+		for( j = 0; j < RESI_KIND_MAX_N; j++ ){
+			reset_pet_resi( pet[i] );
+			pet[i]->resi[j].n = pet[i]->resi[j].max;
+		}
+
+		/* 줤 */
+		pet[i]->fx_data.drunk_rate = (rate_t)0;
+
+		/* Ȥ */
+		take_meal_fill_chr( pet[i] );
 	}
 
 	reset_turn( get_turn() + turn );
-	print_msg( FLG_NULL, MSG_S, MSG_MENU_INN_DO_STAY );
-
 	reset_all( FALSE );
+	reset_glow();
+
+	if( flg_short_stay ){
+		print_msg( FLG_NULL, MSG_S, MSG_MENU_INN_DO_SHORT_STAY );
+	} else {
+		print_msg( FLG_NULL, MSG_S, MSG_MENU_INN_DO_STAY );
+	}
+	print_msg( FLG_NULL, MSG_MENU_INN_CALENDAR,
+			get_calendar_str() );
 
 	if( chk_discount() ){
 		print_words( MSG_NPC_NAME_INN_LANDLORD, MALE,
@@ -1761,7 +1795,7 @@ bool_t	chk_pay( mbr_t *mbr, gold_t price )
 	gold = get_chr_gold( mbr );
 
 	if( gold < price ){
-		print_msg( FLG_NULL, MSG_ERR_MENU_WANTING,
+		print_msg( FLG_MSG_ERR, MSG_ERR_MENU_WANTING,
 				mbr->name, price - gold );
 		return FALSE;
 	}
@@ -1848,6 +1882,8 @@ gold_t	get_price( shop_n_t shop_n, item_t *item, deal_kind_t deal_kind )
 	}
 
 	if( !chk_flg( item->flg, FLG_ITEM_IDENTIFIED ) )
+		price = price * PRICE_NOT_IDENTIFIED_RATE / _100_PERCENT;
+	if( chk_flg( item->flg, FLG_ITEM_CURSED ) )
 		price = (gold_t)0;
 
 	price *= item->n;
@@ -2190,11 +2226,14 @@ gold_t	get_price_light( item_t *item )
 
 /**/
 
-gold_t	get_price_inn( void )
+gold_t	get_price_inn( bool_t flg_short_stay )
 {
 	gold_t	price;
 
-	price = CHARGE_STAY_INN;
+	if( flg_short_stay )
+		price = CHARGE_STAY_INN_SHORT_STAY;
+	else
+		price = CHARGE_STAY_INN_STAY;
 
 	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
 
@@ -3043,7 +3082,7 @@ art_ls_pet_shop_t	*get_art_ls_pet_shop( void )
 bool_t	save_town( void )
 {
 	if( !save_town_ptn( &town_ptn ) ){
-		print_msg( FLG_NULL, MSG_S, MSG_ERR_SAVE_TOWN_PTN );
+		print_msg( FLG_MSG_ERR, MSG_S, MSG_ERR_SAVE_TOWN_PTN );
 		return FALSE;
 	}
 
