@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,8 +25,8 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.h,v 1.20 2004/07/30 16:02:14 bowkenken Exp $
-*****************************************************************/
+* $Id: trap.h,v 1.23 2004/12/06 06:18:18 bowkenken Exp $
+***************************************************************/
 
 #ifndef	TRAP_H
 #define	TRAP_H
@@ -44,7 +44,7 @@
 /* 1 ˤ櫤Ĥ */
 #if	0
 # ifndef	D_TEST_TRAP_KIND
-#  define	D_TEST_TRAP_KIND	TRAP_KIND_CHUTE
+#  define	D_TEST_TRAP_KIND	TRAP_KIND_ARW
 # endif
 #endif
 
