@@ -1,4 +1,4 @@
-/*****************************************************************
+/***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
 * 
@@ -25,11 +25,11 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.36 2004/07/29 07:52:22 bowkenken Exp $
-*****************************************************************/
+* $Id: ver.h,v 1.39 2004/12/07 06:41:08 bowkenken Exp $
+***************************************************************/
 
-#ifndef	GVER_H
-#define	GVER_H
+#ifndef	VER_H
+#define	VER_H
 
 #define	STR_FILE_NAME_GAME	"lnl"
 #define	STR_TITLE	"L&L - Labyrinths & Legends :"
@@ -45,14 +45,18 @@
 #define	STR_VER_GAME	VERSION
 
 #define	STR_FMT_COPYRIGHT	\
-		"\n" \
+		"--------------------------------" \
+		"--------------------------------\n" \
 		"%s version %s\n" \
 		"Copyright (c) %s-%s %s All rights reserved.\n" \
-		"  Created by %s, %s\n" \
-		"  URL   : %s\n" \
-		"  e-mail: %s\n" \
-		"Special thanks %s and you.\n" \
 		"\n" \
+		"Created by %s, %s\n" \
+		"URL   : %s\n" \
+		"e-mail: %s\n" \
+		"\n" \
+		"Special thanks %s and you.\n" \
+		"--------------------------------" \
+		"--------------------------------\n" \
 		""
 
 #define	LS_STR_COPYRIGHT	\
@@ -64,5 +68,4 @@
 		STR_E_MAIL, \
 		STR_THANKS
 
-#endif	/* GVER_H */
-
+#endif	/* VER_H */
